# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.external_service_info import ExternalServiceInfo  # noqa: F401,E501


class StatusInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'external_services': 'list[ExternalServiceInfo]',
        'status': 'dict(str, str)',
        'warning_messages': 'list[str]'
    }

    attribute_map = {
        'external_services': 'externalServices',
        'status': 'status',
        'warning_messages': 'warningMessages'
    }

    def __init__(self, external_services=None, status=None, warning_messages=None):  # noqa: E501
        """StatusInfo - a model defined in Swagger"""  # noqa: E501
        self._external_services = None
        self._status = None
        self._warning_messages = None
        self.discriminator = None
        self.external_services = external_services
        self.status = status
        if warning_messages is not None:
            self.warning_messages = warning_messages

    @property
    def external_services(self):
        """Gets the external_services of this StatusInfo.  # noqa: E501

        An array of external services installed  # noqa: E501

        :return: The external_services of this StatusInfo.  # noqa: E501
        :rtype: list[ExternalServiceInfo]
        """
        return self._external_services

    @external_services.setter
    def external_services(self, external_services):
        """Sets the external_services of this StatusInfo.

        An array of external services installed  # noqa: E501

        :param external_services: The external_services of this StatusInfo.  # noqa: E501
        :type: list[ExternalServiceInfo]
        """
        if external_services is None:
            raise ValueError("Invalid value for `external_services`, must not be `None`")  # noqa: E501

        self._external_services = external_services

    @property
    def status(self):
        """Gets the status of this StatusInfo.  # noqa: E501

        The state of Kiali A hash of key,values with versions of Kiali and state  # noqa: E501

        :return: The status of this StatusInfo.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this StatusInfo.

        The state of Kiali A hash of key,values with versions of Kiali and state  # noqa: E501

        :param status: The status of this StatusInfo.  # noqa: E501
        :type: dict(str, str)
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def warning_messages(self):
        """Gets the warning_messages of this StatusInfo.  # noqa: E501

        An array of warningMessages  # noqa: E501

        :return: The warning_messages of this StatusInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._warning_messages

    @warning_messages.setter
    def warning_messages(self, warning_messages):
        """Sets the warning_messages of this StatusInfo.

        An array of warningMessages  # noqa: E501

        :param warning_messages: The warning_messages of this StatusInfo.  # noqa: E501
        :type: list[str]
        """

        self._warning_messages = warning_messages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatusInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatusInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class NutanixVolumesStorageProfileConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_services_ip': 'str',
        'data_services_port': 'int',
        'flash_mode': 'bool',
        'prism_element_cluster_port': 'int',
        'prism_element_cluster_vip': 'str',
        'prism_element_password': 'str',
        'prism_element_user_name': 'str',
        'storage_container_name': 'str'
    }

    attribute_map = {
        'data_services_ip': 'dataServicesIP',
        'data_services_port': 'dataServicesPort',
        'flash_mode': 'flashMode',
        'prism_element_cluster_port': 'prismElementClusterPort',
        'prism_element_cluster_vip': 'prismElementClusterVIP',
        'prism_element_password': 'prismElementPassword',
        'prism_element_user_name': 'prismElementUserName',
        'storage_container_name': 'storageContainerName'
    }

    def __init__(self, data_services_ip=None, data_services_port=None, flash_mode=None, prism_element_cluster_port=None, prism_element_cluster_vip=None, prism_element_password=None, prism_element_user_name=None, storage_container_name=None):  # noqa: E501
        """NutanixVolumesStorageProfileConfig - a model defined in Swagger"""  # noqa: E501
        self._data_services_ip = None
        self._data_services_port = None
        self._flash_mode = None
        self._prism_element_cluster_port = None
        self._prism_element_cluster_vip = None
        self._prism_element_password = None
        self._prism_element_user_name = None
        self._storage_container_name = None
        self.discriminator = None
        self.data_services_ip = data_services_ip
        self.data_services_port = data_services_port
        if flash_mode is not None:
            self.flash_mode = flash_mode
        self.prism_element_cluster_port = prism_element_cluster_port
        self.prism_element_cluster_vip = prism_element_cluster_vip
        self.prism_element_password = prism_element_password
        self.prism_element_user_name = prism_element_user_name
        self.storage_container_name = storage_container_name

    @property
    def data_services_ip(self):
        """Gets the data_services_ip of this NutanixVolumesStorageProfileConfig.  # noqa: E501


        :return: The data_services_ip of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :rtype: str
        """
        return self._data_services_ip

    @data_services_ip.setter
    def data_services_ip(self, data_services_ip):
        """Sets the data_services_ip of this NutanixVolumesStorageProfileConfig.


        :param data_services_ip: The data_services_ip of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :type: str
        """
        if data_services_ip is None:
            raise ValueError("Invalid value for `data_services_ip`, must not be `None`")  # noqa: E501

        self._data_services_ip = data_services_ip

    @property
    def data_services_port(self):
        """Gets the data_services_port of this NutanixVolumesStorageProfileConfig.  # noqa: E501


        :return: The data_services_port of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :rtype: int
        """
        return self._data_services_port

    @data_services_port.setter
    def data_services_port(self, data_services_port):
        """Sets the data_services_port of this NutanixVolumesStorageProfileConfig.


        :param data_services_port: The data_services_port of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :type: int
        """
        if data_services_port is None:
            raise ValueError("Invalid value for `data_services_port`, must not be `None`")  # noqa: E501

        self._data_services_port = data_services_port

    @property
    def flash_mode(self):
        """Gets the flash_mode of this NutanixVolumesStorageProfileConfig.  # noqa: E501


        :return: The flash_mode of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :rtype: bool
        """
        return self._flash_mode

    @flash_mode.setter
    def flash_mode(self, flash_mode):
        """Sets the flash_mode of this NutanixVolumesStorageProfileConfig.


        :param flash_mode: The flash_mode of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :type: bool
        """

        self._flash_mode = flash_mode

    @property
    def prism_element_cluster_port(self):
        """Gets the prism_element_cluster_port of this NutanixVolumesStorageProfileConfig.  # noqa: E501


        :return: The prism_element_cluster_port of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :rtype: int
        """
        return self._prism_element_cluster_port

    @prism_element_cluster_port.setter
    def prism_element_cluster_port(self, prism_element_cluster_port):
        """Sets the prism_element_cluster_port of this NutanixVolumesStorageProfileConfig.


        :param prism_element_cluster_port: The prism_element_cluster_port of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :type: int
        """
        if prism_element_cluster_port is None:
            raise ValueError("Invalid value for `prism_element_cluster_port`, must not be `None`")  # noqa: E501

        self._prism_element_cluster_port = prism_element_cluster_port

    @property
    def prism_element_cluster_vip(self):
        """Gets the prism_element_cluster_vip of this NutanixVolumesStorageProfileConfig.  # noqa: E501


        :return: The prism_element_cluster_vip of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :rtype: str
        """
        return self._prism_element_cluster_vip

    @prism_element_cluster_vip.setter
    def prism_element_cluster_vip(self, prism_element_cluster_vip):
        """Sets the prism_element_cluster_vip of this NutanixVolumesStorageProfileConfig.


        :param prism_element_cluster_vip: The prism_element_cluster_vip of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :type: str
        """
        if prism_element_cluster_vip is None:
            raise ValueError("Invalid value for `prism_element_cluster_vip`, must not be `None`")  # noqa: E501

        self._prism_element_cluster_vip = prism_element_cluster_vip

    @property
    def prism_element_password(self):
        """Gets the prism_element_password of this NutanixVolumesStorageProfileConfig.  # noqa: E501


        :return: The prism_element_password of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :rtype: str
        """
        return self._prism_element_password

    @prism_element_password.setter
    def prism_element_password(self, prism_element_password):
        """Sets the prism_element_password of this NutanixVolumesStorageProfileConfig.


        :param prism_element_password: The prism_element_password of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :type: str
        """
        if prism_element_password is None:
            raise ValueError("Invalid value for `prism_element_password`, must not be `None`")  # noqa: E501

        self._prism_element_password = prism_element_password

    @property
    def prism_element_user_name(self):
        """Gets the prism_element_user_name of this NutanixVolumesStorageProfileConfig.  # noqa: E501


        :return: The prism_element_user_name of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :rtype: str
        """
        return self._prism_element_user_name

    @prism_element_user_name.setter
    def prism_element_user_name(self, prism_element_user_name):
        """Sets the prism_element_user_name of this NutanixVolumesStorageProfileConfig.


        :param prism_element_user_name: The prism_element_user_name of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :type: str
        """
        if prism_element_user_name is None:
            raise ValueError("Invalid value for `prism_element_user_name`, must not be `None`")  # noqa: E501

        self._prism_element_user_name = prism_element_user_name

    @property
    def storage_container_name(self):
        """Gets the storage_container_name of this NutanixVolumesStorageProfileConfig.  # noqa: E501


        :return: The storage_container_name of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :rtype: str
        """
        return self._storage_container_name

    @storage_container_name.setter
    def storage_container_name(self, storage_container_name):
        """Sets the storage_container_name of this NutanixVolumesStorageProfileConfig.


        :param storage_container_name: The storage_container_name of this NutanixVolumesStorageProfileConfig.  # noqa: E501
        :type: str
        """
        if storage_container_name is None:
            raise ValueError("Invalid value for `storage_container_name`, must not be `None`")  # noqa: E501

        self._storage_container_name = storage_container_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NutanixVolumesStorageProfileConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NutanixVolumesStorageProfileConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from kps_api.api.application_api import ApplicationApi
from kps_api.api.application_status_api import ApplicationStatusApi
from kps_api.api.auditlog_api import AuditlogApi
from kps_api.api.auth_api import AuthApi
from kps_api.api.category_api import CategoryApi
from kps_api.api.certificate_api import CertificateApi
from kps_api.api.cloud_profile_api import CloudProfileApi
from kps_api.api.connector_class_api import ConnectorClassApi
from kps_api.api.connector_config_api import ConnectorConfigApi
from kps_api.api.connector_instance_api import ConnectorInstanceApi
from kps_api.api.connector_stream_api import ConnectorStreamApi
from kps_api.api.container_registry_api import ContainerRegistryApi
from kps_api.api.data_pipeline_api import DataPipelineApi
from kps_api.api.data_source_api import DataSourceApi
from kps_api.api.event_api import EventApi
from kps_api.api.function_api import FunctionApi
from kps_api.api.http_service_proxy_api import HTTPServiceProxyApi
from kps_api.api.helm_api import HelmApi
from kps_api.api.kiali_api import KialiApi
from kps_api.api.kubernetes_cluster_api import KubernetesClusterApi
from kps_api.api.log_api import LogApi
from kps_api.api.log_collector_api import LogCollectorApi
from kps_api.api.ml_model_status_api import MLModelStatusApi
from kps_api.api.ml_model_api import MLModelApi
from kps_api.api.node_api import NodeApi
from kps_api.api.node_info_api import NodeInfoApi
from kps_api.api.project_api import ProjectApi
from kps_api.api.runtime_environment_api import RuntimeEnvironmentApi
from kps_api.api.ssh_api import SSHApi
from kps_api.api.service_binding_api import ServiceBindingApi
from kps_api.api.service_class_api import ServiceClassApi
from kps_api.api.service_domain_api import ServiceDomainApi
from kps_api.api.service_domain_cluster_api import ServiceDomainClusterApi
from kps_api.api.service_domain_info_api import ServiceDomainInfoApi
from kps_api.api.service_instance_api import ServiceInstanceApi
from kps_api.api.storage_profile_api import StorageProfileApi
from kps_api.api.user_api import UserApi
from kps_api.api.user_api_token_api import UserAPITokenApi
from kps_api.api.user_public_key_api import UserPublicKeyApi
# import ApiClient
from kps_api.api_client import ApiClient
from kps_api.configuration import Configuration
# import models into sdk package
from kps_api.models.ai_inferencing_runtime import AIInferencingRuntime
from kps_api.models.ai_inferencing_service_profile import AIInferencingServiceProfile
from kps_api.models.api_error_payload import APIErrorPayload
from kps_api.models.aws_credential import AWSCredential
from kps_api.models.az_credential import AZCredential
from kps_api.models.additional_item import AdditionalItem
from kps_api.models.address import Address
from kps_api.models.addresses import Addresses
from kps_api.models.aggregate_info import AggregateInfo
from kps_api.models.aggregate_spec import AggregateSpec
from kps_api.models.aggregation import Aggregation
from kps_api.models.app import App
from kps_api.models.app_health import AppHealth
from kps_api.models.app_list import AppList
from kps_api.models.app_list_item import AppListItem
from kps_api.models.app_overview import AppOverview
from kps_api.models.app_status import AppStatus
from kps_api.models.application import Application
from kps_api.models.application_containers import ApplicationContainers
from kps_api.models.application_containers_base_object import ApplicationContainersBaseObject
from kps_api.models.application_list_response_payload import ApplicationListResponsePayload
from kps_api.models.application_status import ApplicationStatus
from kps_api.models.application_status_list_payload import ApplicationStatusListPayload
from kps_api.models.application_v2 import ApplicationV2
from kps_api.models.attribute_manifest import AttributeManifest
from kps_api.models.attribute_manifests import AttributeManifests
from kps_api.models.audit_log import AuditLog
from kps_api.models.audit_log_list_response_payload import AuditLogListResponsePayload
from kps_api.models.audit_log_v2 import AuditLogV2
from kps_api.models.audit_log_v2_filter import AuditLogV2Filter
from kps_api.models.audit_log_v2_insert_request import AuditLogV2InsertRequest
from kps_api.models.audit_log_v2_multiple_values import AuditLogV2MultipleValues
from kps_api.models.audit_logs_v2_insert_request import AuditLogsV2InsertRequest
from kps_api.models.authorization_policies import AuthorizationPolicies
from kps_api.models.authorization_policy import AuthorizationPolicy
from kps_api.models.category import Category
from kps_api.models.category_detail_usage_info import CategoryDetailUsageInfo
from kps_api.models.category_info import CategoryInfo
from kps_api.models.category_list_response_payload import CategoryListResponsePayload
from kps_api.models.category_usage import CategoryUsage
from kps_api.models.category_usage_info import CategoryUsageInfo
from kps_api.models.certificates import Certificates
from kps_api.models.chart import Chart
from kps_api.models.cloud_creds import CloudCreds
from kps_api.models.cloud_creds_list_response_payload import CloudCredsListResponsePayload
from kps_api.models.cloud_profile import CloudProfile
from kps_api.models.cloud_profile_info import CloudProfileInfo
from kps_api.models.cloud_profile_list_response_payload import CloudProfileListResponsePayload
from kps_api.models.cloud_profile_project_usage import CloudProfileProjectUsage
from kps_api.models.cloud_profile_usage_info import CloudProfileUsageInfo
from kps_api.models.cluster_config import ClusterConfig
from kps_api.models.cluster_rbac_config import ClusterRbacConfig
from kps_api.models.cluster_rbac_config_spec import ClusterRbacConfigSpec
from kps_api.models.cluster_rbac_configs import ClusterRbacConfigs
from kps_api.models.component_status import ComponentStatus
from kps_api.models.connector_class import ConnectorClass
from kps_api.models.connector_class_list_response_payload import ConnectorClassListResponsePayload
from kps_api.models.connector_class_type import ConnectorClassType
from kps_api.models.connector_config import ConnectorConfig
from kps_api.models.connector_config_list_response_payload import ConnectorConfigListResponsePayload
from kps_api.models.connector_instance import ConnectorInstance
from kps_api.models.connector_instance_inventory import ConnectorInstanceInventory
from kps_api.models.connector_instance_list_response_payload import ConnectorInstanceListResponsePayload
from kps_api.models.connector_parameters_schema import ConnectorParametersSchema
from kps_api.models.connector_parameters_values import ConnectorParametersValues
from kps_api.models.connector_stream import ConnectorStream
from kps_api.models.connector_stream_direction import ConnectorStreamDirection
from kps_api.models.connector_stream_list_response_payload import ConnectorStreamListResponsePayload
from kps_api.models.container_info import ContainerInfo
from kps_api.models.container_registry import ContainerRegistry
from kps_api.models.container_registry_info import ContainerRegistryInfo
from kps_api.models.container_registry_list_payload import ContainerRegistryListPayload
from kps_api.models.container_registry_v2 import ContainerRegistryV2
from kps_api.models.create_document_response import CreateDocumentResponse
from kps_api.models.create_document_response_v2 import CreateDocumentResponseV2
from kps_api.models.credential import Credential
from kps_api.models.dashboard_ref import DashboardRef
from kps_api.models.dashboard_response import DashboardResponse
from kps_api.models.data_ifc_endpoint import DataIfcEndpoint
from kps_api.models.data_pipeline import DataPipeline
from kps_api.models.data_pipeline_containers import DataPipelineContainers
from kps_api.models.data_pipeline_containers_base_object import DataPipelineContainersBaseObject
from kps_api.models.data_pipeline_list_payload import DataPipelineListPayload
from kps_api.models.data_source import DataSource
from kps_api.models.data_source_artifact import DataSourceArtifact
from kps_api.models.data_source_field_info import DataSourceFieldInfo
from kps_api.models.data_source_field_info_v2 import DataSourceFieldInfoV2
from kps_api.models.data_source_field_selector import DataSourceFieldSelector
from kps_api.models.data_source_ifc_info import DataSourceIfcInfo
from kps_api.models.data_source_ifc_ports import DataSourceIfcPorts
from kps_api.models.data_source_list_payload import DataSourceListPayload
from kps_api.models.data_source_v2 import DataSourceV2
from kps_api.models.data_stream import DataStream
from kps_api.models.data_stream_list_payload import DataStreamListPayload
from kps_api.models.delete_document_response import DeleteDocumentResponse
from kps_api.models.delete_document_response_v2 import DeleteDocumentResponseV2
from kps_api.models.delete_request import DeleteRequest
from kps_api.models.destination_rule import DestinationRule
from kps_api.models.destination_rules import DestinationRules
from kps_api.models.docker_profile import DockerProfile
from kps_api.models.docker_profile_list_payload import DockerProfileListPayload
from kps_api.models.ebs_storage_profile_config import EBSStorageProfileConfig
from kps_api.models.edge import Edge
from kps_api.models.edge_cert import EdgeCert
from kps_api.models.edge_cert_list_payload import EdgeCertListPayload
from kps_api.models.edge_cert_lock_param import EdgeCertLockParam
from kps_api.models.edge_cluster import EdgeCluster
from kps_api.models.edge_cluster_list_payload import EdgeClusterListPayload
from kps_api.models.edge_data import EdgeData
from kps_api.models.edge_device import EdgeDevice
from kps_api.models.edge_device_info import EdgeDeviceInfo
from kps_api.models.edge_device_info_list_payload import EdgeDeviceInfoListPayload
from kps_api.models.edge_device_list_payload import EdgeDeviceListPayload
from kps_api.models.edge_device_onboard_info import EdgeDeviceOnboardInfo
from kps_api.models.edge_device_with_cluster_info import EdgeDeviceWithClusterInfo
from kps_api.models.edge_info_list_payload import EdgeInfoListPayload
from kps_api.models.edge_inventory_deleted import EdgeInventoryDeleted
from kps_api.models.edge_inventory_delta_payload import EdgeInventoryDeltaPayload
from kps_api.models.edge_inventory_delta_response import EdgeInventoryDeltaResponse
from kps_api.models.edge_inventory_details import EdgeInventoryDetails
from kps_api.models.edge_list_payload import EdgeListPayload
from kps_api.models.edge_service import EdgeService
from kps_api.models.edge_upgrade import EdgeUpgrade
from kps_api.models.edge_upgrade_core import EdgeUpgradeCore
from kps_api.models.edge_upgrade_list_payload import EdgeUpgradeListPayload
from kps_api.models.edge_usage_info import EdgeUsageInfo
from kps_api.models.edge_v2 import EdgeV2
from kps_api.models.edge_wrapper import EdgeWrapper
from kps_api.models.elements import Elements
from kps_api.models.email_availability import EmailAvailability
from kps_api.models.endpoint import Endpoint
from kps_api.models.endpoints import Endpoints
from kps_api.models.entity_version_metadata import EntityVersionMetadata
from kps_api.models.envoy_filter import EnvoyFilter
from kps_api.models.envoy_filters import EnvoyFilters
from kps_api.models.event import Event
from kps_api.models.event_filter import EventFilter
from kps_api.models.event_filter_v2 import EventFilterV2
from kps_api.models.event_type import EventType
from kps_api.models.event_upsert_request import EventUpsertRequest
from kps_api.models.execute_edge_upgrade import ExecuteEdgeUpgrade
from kps_api.models.execute_edge_upgrade_data import ExecuteEdgeUpgradeData
from kps_api.models.execute_edge_upgrade_id import ExecuteEdgeUpgradeID
from kps_api.models.external_link import ExternalLink
from kps_api.models.external_service_info import ExternalServiceInfo
from kps_api.models.features import Features
from kps_api.models.fields_v1 import FieldsV1
from kps_api.models.function import Function
from kps_api.models.function_list_payload import FunctionListPayload
from kps_api.models.gcp_credential import GCPCredential
from kps_api.models.gateway import Gateway
from kps_api.models.gateways import Gateways
from kps_api.models.get_edge_cluster_handle_payload import GetEdgeClusterHandlePayload
from kps_api.models.get_handle_payload import GetHandlePayload
from kps_api.models.grafana_info import GrafanaInfo
from kps_api.models.graph_config import GraphConfig
from kps_api.models.http_service_proxy import HTTPServiceProxy
from kps_api.models.http_service_proxy_create_param_payload import HTTPServiceProxyCreateParamPayload
from kps_api.models.http_service_proxy_create_response_payload import HTTPServiceProxyCreateResponsePayload
from kps_api.models.http_service_proxy_list_payload import HTTPServiceProxyListPayload
from kps_api.models.http_service_proxy_update_param_payload import HTTPServiceProxyUpdateParamPayload
from kps_api.models.http_service_proxy_update_response_payload import HTTPServiceProxyUpdateResponsePayload
from kps_api.models.helm_app_metadata import HelmAppMetadata
from kps_api.models.helm_template_response import HelmTemplateResponse
from kps_api.models.http_api_spec import HttpApiSpec
from kps_api.models.http_api_spec_binding import HttpApiSpecBinding
from kps_api.models.http_api_spec_bindings import HttpApiSpecBindings
from kps_api.models.http_api_specs import HttpApiSpecs
from kps_api.models.infra_config import InfraConfig
from kps_api.models.istio_adapter import IstioAdapter
from kps_api.models.istio_adapters import IstioAdapters
from kps_api.models.istio_check import IstioCheck
from kps_api.models.istio_component_status import IstioComponentStatus
from kps_api.models.istio_config_details import IstioConfigDetails
from kps_api.models.istio_config_list import IstioConfigList
from kps_api.models.istio_config_permissions import IstioConfigPermissions
from kps_api.models.istio_handler import IstioHandler
from kps_api.models.istio_handlers import IstioHandlers
from kps_api.models.istio_instance import IstioInstance
from kps_api.models.istio_instances import IstioInstances
from kps_api.models.istio_rule import IstioRule
from kps_api.models.istio_rules import IstioRules
from kps_api.models.istio_template import IstioTemplate
from kps_api.models.istio_templates import IstioTemplates
from kps_api.models.istio_validation import IstioValidation
from kps_api.models.istio_validation_key import IstioValidationKey
from kps_api.models.istio_validation_summary import IstioValidationSummary
from kps_api.models.istio_validations import IstioValidations
from kps_api.models.iter8_criteria import Iter8Criteria
from kps_api.models.iter8_criteria_detail import Iter8CriteriaDetail
from kps_api.models.iter8_experiment_detail import Iter8ExperimentDetail
from kps_api.models.iter8_experiment_item import Iter8ExperimentItem
from kps_api.models.iter8_info import Iter8Info
from kps_api.models.iter8_metric import Iter8Metric
from kps_api.models.iter8_success_crideria_status import Iter8SuccessCrideriaStatus
from kps_api.models.iter8_traffic_control import Iter8TrafficControl
from kps_api.models.json_text import JSONText
from kps_api.models.jaeger_info import JaegerInfo
from kps_api.models.k8s_config import K8sConfig
from kps_api.models.k8s_dashboard_token_response_payload import K8sDashboardTokenResponsePayload
from kps_api.models.k8s_dashboard_viewonly_user_list_payload import K8sDashboardViewonlyUserListPayload
from kps_api.models.k8s_dashboard_viewonly_user_params import K8sDashboardViewonlyUserParams
from kps_api.models.k8s_dashboard_viewonly_user_update_payload import K8sDashboardViewonlyUserUpdatePayload
from kps_api.models.key_value import KeyValue
from kps_api.models.kiali_metric import KialiMetric
from kps_api.models.kiali_metrics import KialiMetrics
from kps_api.models.kube_config_payload import KubeConfigPayload
from kps_api.models.kubernetes_cluster import KubernetesCluster
from kps_api.models.kubernetes_cluster_cert import KubernetesClusterCert
from kps_api.models.kubernetes_cluster_handle_payload import KubernetesClusterHandlePayload
from kps_api.models.kubernetes_cluster_installer import KubernetesClusterInstaller
from kps_api.models.kubernetes_clusters_list_response_payload import KubernetesClustersListResponsePayload
from kps_api.models.log import Log
from kps_api.models.log_collector import LogCollector
from kps_api.models.log_collector_cloudwatch import LogCollectorCloudwatch
from kps_api.models.log_collector_destination import LogCollectorDestination
from kps_api.models.log_collector_kinesis import LogCollectorKinesis
from kps_api.models.log_collector_kinesis_type import LogCollectorKinesisType
from kps_api.models.log_collector_list_payload import LogCollectorListPayload
from kps_api.models.log_collector_sources import LogCollectorSources
from kps_api.models.log_collector_stackdriver import LogCollectorStackdriver
from kps_api.models.log_collector_status import LogCollectorStatus
from kps_api.models.log_collector_type import LogCollectorType
from kps_api.models.log_download_payload import LogDownloadPayload
from kps_api.models.log_entries_list_payload import LogEntriesListPayload
from kps_api.models.log_entry import LogEntry
from kps_api.models.log_stream import LogStream
from kps_api.models.log_stream_response_payload import LogStreamResponsePayload
from kps_api.models.log_tag import LogTag
from kps_api.models.log_upload_complete_payload import LogUploadCompletePayload
from kps_api.models.log_upload_payload import LogUploadPayload
from kps_api.models.log_upload_status import LogUploadStatus
from kps_api.models.login_response import LoginResponse
from kps_api.models.ml_model import MLModel
from kps_api.models.ml_model_list_response_payload import MLModelListResponsePayload
from kps_api.models.ml_model_metadata import MLModelMetadata
from kps_api.models.ml_model_status import MLModelStatus
from kps_api.models.ml_model_status_list_payload import MLModelStatusListPayload
from kps_api.models.ml_model_version import MLModelVersion
from kps_api.models.ml_model_version_status import MLModelVersionStatus
from kps_api.models.ml_model_version_url_get_response_payload import MLModelVersionURLGetResponsePayload
from kps_api.models.mtls_status import MTLSStatus
from kps_api.models.managed_fields_entry import ManagedFieldsEntry
from kps_api.models.managed_fields_operation_type import ManagedFieldsOperationType
from kps_api.models.matrix import Matrix
from kps_api.models.mesh_policies import MeshPolicies
from kps_api.models.mesh_policy import MeshPolicy
from kps_api.models.mesh_policy_spec import MeshPolicySpec
from kps_api.models.metrics import Metrics
from kps_api.models.monitoring_dashboard import MonitoringDashboard
from kps_api.models.monitoring_dashboard_external_link_variables import MonitoringDashboardExternalLinkVariables
from kps_api.models.namespace import Namespace
from kps_api.models.namespace_app_health import NamespaceAppHealth
from kps_api.models.namespace_overview import NamespaceOverview
from kps_api.models.nested_aggregate_spec import NestedAggregateSpec
from kps_api.models.node import Node
from kps_api.models.node_data import NodeData
from kps_api.models.node_health_status import NodeHealthStatus
from kps_api.models.node_info import NodeInfo
from kps_api.models.node_info_list_payload import NodeInfoListPayload
from kps_api.models.node_list_payload import NodeListPayload
from kps_api.models.node_onboard_info import NodeOnboardInfo
from kps_api.models.node_role import NodeRole
from kps_api.models.node_wrapper import NodeWrapper
from kps_api.models.notification_topics import NotificationTopics
from kps_api.models.nutanix_volumes_storage_profile_config import NutanixVolumesStorageProfileConfig
from kps_api.models.o_auth_codes import OAuthCodes
from kps_api.models.object_meta import ObjectMeta
from kps_api.models.object_request_base_application import ObjectRequestBaseApplication
from kps_api.models.object_request_base_application_containers import ObjectRequestBaseApplicationContainers
from kps_api.models.object_request_base_category import ObjectRequestBaseCategory
from kps_api.models.object_request_base_cloud_creds import ObjectRequestBaseCloudCreds
from kps_api.models.object_request_base_data_pipeline_containers import ObjectRequestBaseDataPipelineContainers
from kps_api.models.object_request_base_data_source import ObjectRequestBaseDataSource
from kps_api.models.object_request_base_data_stream import ObjectRequestBaseDataStream
from kps_api.models.object_request_base_docker_profile import ObjectRequestBaseDockerProfile
from kps_api.models.object_request_base_edge import ObjectRequestBaseEdge
from kps_api.models.object_request_base_edge_info import ObjectRequestBaseEdgeInfo
from kps_api.models.object_request_base_execute_edge_upgrade import ObjectRequestBaseExecuteEdgeUpgrade
from kps_api.models.object_request_base_log_collector import ObjectRequestBaseLogCollector
from kps_api.models.object_request_base_log_stream import ObjectRequestBaseLogStream
from kps_api.models.object_request_base_ml_model import ObjectRequestBaseMLModel
from kps_api.models.object_request_base_project import ObjectRequestBaseProject
from kps_api.models.object_request_base_project_service import ObjectRequestBaseProjectService
from kps_api.models.object_request_base_script import ObjectRequestBaseScript
from kps_api.models.object_request_base_script_runtime import ObjectRequestBaseScriptRuntime
from kps_api.models.object_request_base_service_binding import ObjectRequestBaseServiceBinding
from kps_api.models.object_request_base_service_instance import ObjectRequestBaseServiceInstance
from kps_api.models.object_request_base_software_update import ObjectRequestBaseSoftwareUpdate
from kps_api.models.object_request_log_upload import ObjectRequestLogUpload
from kps_api.models.object_request_setup_ssh_tunneling import ObjectRequestSetupSSHTunneling
from kps_api.models.object_request_teardown_ssh_tunneling import ObjectRequestTeardownSSHTunneling
from kps_api.models.object_response_log_upload_complete import ObjectResponseLogUploadComplete
from kps_api.models.owner_reference import OwnerReference
from kps_api.models.peer_authentication import PeerAuthentication
from kps_api.models.peer_authentications import PeerAuthentications
from kps_api.models.pod import Pod
from kps_api.models.pod_metrics import PodMetrics
from kps_api.models.pod_status import PodStatus
from kps_api.models.pods import Pods
from kps_api.models.policies import Policies
from kps_api.models.policy import Policy
from kps_api.models.port import Port
from kps_api.models.ports import Ports
from kps_api.models.process import Process
from kps_api.models.process_id import ProcessID
from kps_api.models.project import Project
from kps_api.models.project_list_payload import ProjectListPayload
from kps_api.models.project_role import ProjectRole
from kps_api.models.project_role_list_payload import ProjectRoleListPayload
from kps_api.models.project_service import ProjectService
from kps_api.models.project_service_list_payload import ProjectServiceListPayload
from kps_api.models.project_user_info import ProjectUserInfo
from kps_api.models.protocol_traffic import ProtocolTraffic
from kps_api.models.proxy_call_payload import ProxyCallPayload
from kps_api.models.proxy_request import ProxyRequest
from kps_api.models.proxy_response import ProxyResponse
from kps_api.models.proxy_response_payload import ProxyResponsePayload
from kps_api.models.quota_spec import QuotaSpec
from kps_api.models.quota_spec_binding import QuotaSpecBinding
from kps_api.models.quota_spec_bindings import QuotaSpecBindings
from kps_api.models.quota_specs import QuotaSpecs
from kps_api.models.raw_message import RawMessage
from kps_api.models.rbac_config import RbacConfig
from kps_api.models.rbac_configs import RbacConfigs
from kps_api.models.reference import Reference
from kps_api.models.reference_type import ReferenceType
from kps_api.models.render_application_payload import RenderApplicationPayload
from kps_api.models.render_application_response_payload import RenderApplicationResponsePayload
from kps_api.models.report_sensors_request import ReportSensorsRequest
from kps_api.models.request_authentication import RequestAuthentication
from kps_api.models.request_authentications import RequestAuthentications
from kps_api.models.request_health import RequestHealth
from kps_api.models.request_log_download_payload import RequestLogDownloadPayload
from kps_api.models.request_log_upload_payload import RequestLogUploadPayload
from kps_api.models.resource_permissions import ResourcePermissions
from kps_api.models.resources_permissions import ResourcesPermissions
from kps_api.models.response_base import ResponseBase
from kps_api.models.response_base_edge import ResponseBaseEdge
from kps_api.models.response_detail import ResponseDetail
from kps_api.models.response_flags import ResponseFlags
from kps_api.models.response_hosts import ResponseHosts
from kps_api.models.responses import Responses
from kps_api.models.retention_info import RetentionInfo
from kps_api.models.runtime import Runtime
from kps_api.models.runtime_environment import RuntimeEnvironment
from kps_api.models.runtime_environment_list_payload import RuntimeEnvironmentListPayload
from kps_api.models.sample_pair import SamplePair
from kps_api.models.sample_stream import SampleStream
from kps_api.models.schema import Schema
from kps_api.models.script import Script
from kps_api.models.script_list_payload import ScriptListPayload
from kps_api.models.script_param import ScriptParam
from kps_api.models.script_param_value import ScriptParamValue
from kps_api.models.script_runtime import ScriptRuntime
from kps_api.models.script_runtime_list_payload import ScriptRuntimeListPayload
from kps_api.models.sensor import Sensor
from kps_api.models.sensor_list_payload import SensorListPayload
from kps_api.models.serial_number_payload import SerialNumberPayload
from kps_api.models.service import Service
from kps_api.models.service_binding import ServiceBinding
from kps_api.models.service_binding_list_payload import ServiceBindingListPayload
from kps_api.models.service_binding_param import ServiceBindingParam
from kps_api.models.service_binding_resource import ServiceBindingResource
from kps_api.models.service_binding_resource_type import ServiceBindingResourceType
from kps_api.models.service_binding_result import ServiceBindingResult
from kps_api.models.service_binding_schema import ServiceBindingSchema
from kps_api.models.service_binding_state_type import ServiceBindingStateType
from kps_api.models.service_binding_status import ServiceBindingStatus
from kps_api.models.service_binding_status_list_payload import ServiceBindingStatusListPayload
from kps_api.models.service_class import ServiceClass
from kps_api.models.service_class_list_payload import ServiceClassListPayload
from kps_api.models.service_class_schemas import ServiceClassSchemas
from kps_api.models.service_class_scope_type import ServiceClassScopeType
from kps_api.models.service_class_state_type import ServiceClassStateType
from kps_api.models.service_class_tag import ServiceClassTag
from kps_api.models.service_details import ServiceDetails
from kps_api.models.service_domain import ServiceDomain
from kps_api.models.service_domain_cluster import ServiceDomainCluster
from kps_api.models.service_domain_clusters_list_response_payload import ServiceDomainClustersListResponsePayload
from kps_api.models.service_domain_get_handle_payload import ServiceDomainGetHandlePayload
from kps_api.models.service_domain_info import ServiceDomainInfo
from kps_api.models.service_domain_info_list_payload import ServiceDomainInfoListPayload
from kps_api.models.service_domain_list_payload import ServiceDomainListPayload
from kps_api.models.service_domain_profile import ServiceDomainProfile
from kps_api.models.service_entries import ServiceEntries
from kps_api.models.service_entry import ServiceEntry
from kps_api.models.service_health import ServiceHealth
from kps_api.models.service_instance import ServiceInstance
from kps_api.models.service_instance_list_payload import ServiceInstanceListPayload
from kps_api.models.service_instance_param import ServiceInstanceParam
from kps_api.models.service_instance_schema import ServiceInstanceSchema
from kps_api.models.service_instance_state_type import ServiceInstanceStateType
from kps_api.models.service_instance_status import ServiceInstanceStatus
from kps_api.models.service_instance_status_list_payload import ServiceInstanceStatusListPayload
from kps_api.models.service_list import ServiceList
from kps_api.models.service_mesh_policies import ServiceMeshPolicies
from kps_api.models.service_mesh_policy import ServiceMeshPolicy
from kps_api.models.service_mesh_rbac_config import ServiceMeshRbacConfig
from kps_api.models.service_mesh_rbac_configs import ServiceMeshRbacConfigs
from kps_api.models.service_name import ServiceName
from kps_api.models.service_overview import ServiceOverview
from kps_api.models.service_role import ServiceRole
from kps_api.models.service_role_binding import ServiceRoleBinding
from kps_api.models.service_role_bindings import ServiceRoleBindings
from kps_api.models.service_roles import ServiceRoles
from kps_api.models.services import Services
from kps_api.models.services_overview import ServicesOverview
from kps_api.models.severity_level import SeverityLevel
from kps_api.models.sidecar import Sidecar
from kps_api.models.sidecars import Sidecars
from kps_api.models.software_download_command import SoftwareDownloadCommand
from kps_api.models.software_download_create import SoftwareDownloadCreate
from kps_api.models.software_download_update import SoftwareDownloadUpdate
from kps_api.models.software_downloaded_service_domain_list_payload import SoftwareDownloadedServiceDomainListPayload
from kps_api.models.software_release import SoftwareRelease
from kps_api.models.software_release_list_payload import SoftwareReleaseListPayload
from kps_api.models.software_update_batch import SoftwareUpdateBatch
from kps_api.models.software_update_batch_list_payload import SoftwareUpdateBatchListPayload
from kps_api.models.software_update_batch_type import SoftwareUpdateBatchType
from kps_api.models.software_update_credentials import SoftwareUpdateCredentials
from kps_api.models.software_update_credentials_access_type import SoftwareUpdateCredentialsAccessType
from kps_api.models.software_update_credentials_create_payload import SoftwareUpdateCredentialsCreatePayload
from kps_api.models.software_update_service_domain import SoftwareUpdateServiceDomain
from kps_api.models.software_update_service_domain_list_payload import SoftwareUpdateServiceDomainListPayload
from kps_api.models.software_update_state import SoftwareUpdateState
from kps_api.models.software_update_state_type import SoftwareUpdateStateType
from kps_api.models.software_upgrade_command import SoftwareUpgradeCommand
from kps_api.models.software_upgrade_create import SoftwareUpgradeCreate
from kps_api.models.software_upgrade_update import SoftwareUpgradeUpdate
from kps_api.models.span import Span
from kps_api.models.span_id import SpanID
from kps_api.models.status_info import StatusInfo
from kps_api.models.storage_profile import StorageProfile
from kps_api.models.storage_profile_list_response_payload import StorageProfileListResponsePayload
from kps_api.models.tenant import Tenant
from kps_api.models.tenant_info import TenantInfo
from kps_api.models.tenant_profile import TenantProfile
from kps_api.models.tenant_props import TenantProps
from kps_api.models.three_scale_handler import ThreeScaleHandler
from kps_api.models.three_scale_handlers import ThreeScaleHandlers
from kps_api.models.three_scale_info import ThreeScaleInfo
from kps_api.models.three_scale_service_rule import ThreeScaleServiceRule
from kps_api.models.time import Time
from kps_api.models.trace import Trace
from kps_api.models.trace_id import TraceID
from kps_api.models.transformation_args import TransformationArgs
from kps_api.models.uid import UID
from kps_api.models.update_document_response import UpdateDocumentResponse
from kps_api.models.update_document_response_v2 import UpdateDocumentResponseV2
from kps_api.models.user import User
from kps_api.models.user_api_token import UserApiToken
from kps_api.models.user_api_token_create_payload import UserApiTokenCreatePayload
from kps_api.models.user_api_token_created import UserApiTokenCreated
from kps_api.models.user_list_payload import UserListPayload
from kps_api.models.user_props import UserProps
from kps_api.models.user_public_key import UserPublicKey
from kps_api.models.user_public_key_update_payload import UserPublicKeyUpdatePayload
from kps_api.models.v_sphere_storage_profile_config import VSphereStorageProfileConfig
from kps_api.models.value_type import ValueType
from kps_api.models.virtual_service import VirtualService
from kps_api.models.virtual_services import VirtualServices
from kps_api.models.ws_messaging_log_stream import WSMessagingLogStream
from kps_api.models.workload import Workload
from kps_api.models.workload_entries import WorkloadEntries
from kps_api.models.workload_entry import WorkloadEntry
from kps_api.models.workload_health import WorkloadHealth
from kps_api.models.workload_item import WorkloadItem
from kps_api.models.workload_list import WorkloadList
from kps_api.models.workload_list_item import WorkloadListItem
from kps_api.models.workload_overview import WorkloadOverview
from kps_api.models.workload_overviews import WorkloadOverviews
from kps_api.models.workload_status import WorkloadStatus
from kps_api.models.wstun_payload import WstunPayload
from kps_api.models.wstun_request import WstunRequest
from kps_api.models.wstun_teardown_request import WstunTeardownRequest



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MeshPolicySpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'origin_is_optional': 'object',
        'origins': 'object',
        'peer_is_optional': 'object',
        'peers': 'object',
        'principal_binding': 'object',
        'targets': 'object'
    }

    attribute_map = {
        'origin_is_optional': 'originIsOptional',
        'origins': 'origins',
        'peer_is_optional': 'peerIsOptional',
        'peers': 'peers',
        'principal_binding': 'principalBinding',
        'targets': 'targets'
    }

    def __init__(self, origin_is_optional=None, origins=None, peer_is_optional=None, peers=None, principal_binding=None, targets=None):  # noqa: E501
        """MeshPolicySpec - a model defined in Swagger"""  # noqa: E501
        self._origin_is_optional = None
        self._origins = None
        self._peer_is_optional = None
        self._peers = None
        self._principal_binding = None
        self._targets = None
        self.discriminator = None
        if origin_is_optional is not None:
            self.origin_is_optional = origin_is_optional
        if origins is not None:
            self.origins = origins
        if peer_is_optional is not None:
            self.peer_is_optional = peer_is_optional
        if peers is not None:
            self.peers = peers
        if principal_binding is not None:
            self.principal_binding = principal_binding
        if targets is not None:
            self.targets = targets

    @property
    def origin_is_optional(self):
        """Gets the origin_is_optional of this MeshPolicySpec.  # noqa: E501


        :return: The origin_is_optional of this MeshPolicySpec.  # noqa: E501
        :rtype: object
        """
        return self._origin_is_optional

    @origin_is_optional.setter
    def origin_is_optional(self, origin_is_optional):
        """Sets the origin_is_optional of this MeshPolicySpec.


        :param origin_is_optional: The origin_is_optional of this MeshPolicySpec.  # noqa: E501
        :type: object
        """

        self._origin_is_optional = origin_is_optional

    @property
    def origins(self):
        """Gets the origins of this MeshPolicySpec.  # noqa: E501


        :return: The origins of this MeshPolicySpec.  # noqa: E501
        :rtype: object
        """
        return self._origins

    @origins.setter
    def origins(self, origins):
        """Sets the origins of this MeshPolicySpec.


        :param origins: The origins of this MeshPolicySpec.  # noqa: E501
        :type: object
        """

        self._origins = origins

    @property
    def peer_is_optional(self):
        """Gets the peer_is_optional of this MeshPolicySpec.  # noqa: E501


        :return: The peer_is_optional of this MeshPolicySpec.  # noqa: E501
        :rtype: object
        """
        return self._peer_is_optional

    @peer_is_optional.setter
    def peer_is_optional(self, peer_is_optional):
        """Sets the peer_is_optional of this MeshPolicySpec.


        :param peer_is_optional: The peer_is_optional of this MeshPolicySpec.  # noqa: E501
        :type: object
        """

        self._peer_is_optional = peer_is_optional

    @property
    def peers(self):
        """Gets the peers of this MeshPolicySpec.  # noqa: E501


        :return: The peers of this MeshPolicySpec.  # noqa: E501
        :rtype: object
        """
        return self._peers

    @peers.setter
    def peers(self, peers):
        """Sets the peers of this MeshPolicySpec.


        :param peers: The peers of this MeshPolicySpec.  # noqa: E501
        :type: object
        """

        self._peers = peers

    @property
    def principal_binding(self):
        """Gets the principal_binding of this MeshPolicySpec.  # noqa: E501


        :return: The principal_binding of this MeshPolicySpec.  # noqa: E501
        :rtype: object
        """
        return self._principal_binding

    @principal_binding.setter
    def principal_binding(self, principal_binding):
        """Sets the principal_binding of this MeshPolicySpec.


        :param principal_binding: The principal_binding of this MeshPolicySpec.  # noqa: E501
        :type: object
        """

        self._principal_binding = principal_binding

    @property
    def targets(self):
        """Gets the targets of this MeshPolicySpec.  # noqa: E501


        :return: The targets of this MeshPolicySpec.  # noqa: E501
        :rtype: object
        """
        return self._targets

    @targets.setter
    def targets(self, targets):
        """Sets the targets of this MeshPolicySpec.


        :param targets: The targets of this MeshPolicySpec.  # noqa: E501
        :type: object
        """

        self._targets = targets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MeshPolicySpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MeshPolicySpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.data_pipeline_api import DataPipelineApi  # noqa: E501
from kps_api.rest import ApiException


class TestDataPipelineApi(unittest.TestCase):
    """DataPipelineApi unit test stubs"""

    def setUp(self):
        self.api = api.data_pipeline_api.DataPipelineApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_data_pipeline_create(self):
        """Test case for data_pipeline_create

        Creates a data pipeline.  # noqa: E501
        """
        pass

    def test_data_pipeline_delete(self):
        """Test case for data_pipeline_delete

        Deletes data pipeline by its ID.  # noqa: E501
        """
        pass

    def test_data_pipeline_get(self):
        """Test case for data_pipeline_get

        Lists data pipeline by its ID.  # noqa: E501
        """
        pass

    def test_data_pipeline_list(self):
        """Test case for data_pipeline_list

        Gets data pipelines.  # noqa: E501
        """
        pass

    def test_data_pipeline_update(self):
        """Test case for data_pipeline_update

        Updates a data pipeline by its ID  # noqa: E501
        """
        pass

    def test_get_data_pipeline_containers(self):
        """Test case for get_data_pipeline_containers

        Get containers of a data pipeline specified by Datapipeline ID running on a specific edge.  # noqa: E501
        """
        pass

    def test_project_get_data_pipelines(self):
        """Test case for project_get_data_pipelines

        Gets data pipelines for a project.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.attribute_manifest import AttributeManifest  # noqa: F401,E501
from kps_api.models.authorization_policy import AuthorizationPolicy  # noqa: F401,E501
from kps_api.models.cluster_rbac_config import ClusterRbacConfig  # noqa: F401,E501
from kps_api.models.destination_rule import DestinationRule  # noqa: F401,E501
from kps_api.models.envoy_filter import EnvoyFilter  # noqa: F401,E501
from kps_api.models.gateway import Gateway  # noqa: F401,E501
from kps_api.models.http_api_spec import HttpApiSpec  # noqa: F401,E501
from kps_api.models.http_api_spec_binding import HttpApiSpecBinding  # noqa: F401,E501
from kps_api.models.istio_adapter import IstioAdapter  # noqa: F401,E501
from kps_api.models.istio_handler import IstioHandler  # noqa: F401,E501
from kps_api.models.istio_instance import IstioInstance  # noqa: F401,E501
from kps_api.models.istio_rule import IstioRule  # noqa: F401,E501
from kps_api.models.istio_template import IstioTemplate  # noqa: F401,E501
from kps_api.models.istio_validation import IstioValidation  # noqa: F401,E501
from kps_api.models.mesh_policy import MeshPolicy  # noqa: F401,E501
from kps_api.models.namespace import Namespace  # noqa: F401,E501
from kps_api.models.peer_authentication import PeerAuthentication  # noqa: F401,E501
from kps_api.models.policy import Policy  # noqa: F401,E501
from kps_api.models.quota_spec import QuotaSpec  # noqa: F401,E501
from kps_api.models.quota_spec_binding import QuotaSpecBinding  # noqa: F401,E501
from kps_api.models.rbac_config import RbacConfig  # noqa: F401,E501
from kps_api.models.request_authentication import RequestAuthentication  # noqa: F401,E501
from kps_api.models.resource_permissions import ResourcePermissions  # noqa: F401,E501
from kps_api.models.service_entry import ServiceEntry  # noqa: F401,E501
from kps_api.models.service_mesh_policy import ServiceMeshPolicy  # noqa: F401,E501
from kps_api.models.service_mesh_rbac_config import ServiceMeshRbacConfig  # noqa: F401,E501
from kps_api.models.service_role import ServiceRole  # noqa: F401,E501
from kps_api.models.service_role_binding import ServiceRoleBinding  # noqa: F401,E501
from kps_api.models.sidecar import Sidecar  # noqa: F401,E501
from kps_api.models.virtual_service import VirtualService  # noqa: F401,E501
from kps_api.models.workload_entry import WorkloadEntry  # noqa: F401,E501


class IstioConfigDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'adapter': 'IstioAdapter',
        'attribute_manifest': 'AttributeManifest',
        'authorization_policy': 'AuthorizationPolicy',
        'cluster_rbac_config': 'ClusterRbacConfig',
        'destination_rule': 'DestinationRule',
        'envoy_filter': 'EnvoyFilter',
        'gateway': 'Gateway',
        'handler': 'IstioHandler',
        'http_api_spec': 'HttpApiSpec',
        'http_api_spec_binding': 'HttpApiSpecBinding',
        'instance': 'IstioInstance',
        'istio_validation': 'IstioValidation',
        'mesh_policy': 'MeshPolicy',
        'namespace': 'Namespace',
        'object_type': 'str',
        'peer_authentication': 'PeerAuthentication',
        'permissions': 'ResourcePermissions',
        'policy': 'Policy',
        'quota_spec': 'QuotaSpec',
        'quota_spec_binding': 'QuotaSpecBinding',
        'rbac_config': 'RbacConfig',
        'request_authentication': 'RequestAuthentication',
        'rule': 'IstioRule',
        'service_entry': 'ServiceEntry',
        'service_mesh_policy': 'ServiceMeshPolicy',
        'service_mesh_rbac_config': 'ServiceMeshRbacConfig',
        'service_role': 'ServiceRole',
        'service_role_binding': 'ServiceRoleBinding',
        'sidecar': 'Sidecar',
        'template': 'IstioTemplate',
        'virtual_service': 'VirtualService',
        'workload_entry': 'WorkloadEntry'
    }

    attribute_map = {
        'adapter': 'adapter',
        'attribute_manifest': 'attributeManifest',
        'authorization_policy': 'authorizationPolicy',
        'cluster_rbac_config': 'clusterRbacConfig',
        'destination_rule': 'destinationRule',
        'envoy_filter': 'envoyFilter',
        'gateway': 'gateway',
        'handler': 'handler',
        'http_api_spec': 'httpApiSpec',
        'http_api_spec_binding': 'httpApiSpecBinding',
        'instance': 'instance',
        'istio_validation': 'istioValidation',
        'mesh_policy': 'meshPolicy',
        'namespace': 'namespace',
        'object_type': 'objectType',
        'peer_authentication': 'peerAuthentication',
        'permissions': 'permissions',
        'policy': 'policy',
        'quota_spec': 'quotaSpec',
        'quota_spec_binding': 'quotaSpecBinding',
        'rbac_config': 'rbacConfig',
        'request_authentication': 'requestAuthentication',
        'rule': 'rule',
        'service_entry': 'serviceEntry',
        'service_mesh_policy': 'serviceMeshPolicy',
        'service_mesh_rbac_config': 'serviceMeshRbacConfig',
        'service_role': 'serviceRole',
        'service_role_binding': 'serviceRoleBinding',
        'sidecar': 'sidecar',
        'template': 'template',
        'virtual_service': 'virtualService',
        'workload_entry': 'workloadEntry'
    }

    def __init__(self, adapter=None, attribute_manifest=None, authorization_policy=None, cluster_rbac_config=None, destination_rule=None, envoy_filter=None, gateway=None, handler=None, http_api_spec=None, http_api_spec_binding=None, instance=None, istio_validation=None, mesh_policy=None, namespace=None, object_type=None, peer_authentication=None, permissions=None, policy=None, quota_spec=None, quota_spec_binding=None, rbac_config=None, request_authentication=None, rule=None, service_entry=None, service_mesh_policy=None, service_mesh_rbac_config=None, service_role=None, service_role_binding=None, sidecar=None, template=None, virtual_service=None, workload_entry=None):  # noqa: E501
        """IstioConfigDetails - a model defined in Swagger"""  # noqa: E501
        self._adapter = None
        self._attribute_manifest = None
        self._authorization_policy = None
        self._cluster_rbac_config = None
        self._destination_rule = None
        self._envoy_filter = None
        self._gateway = None
        self._handler = None
        self._http_api_spec = None
        self._http_api_spec_binding = None
        self._instance = None
        self._istio_validation = None
        self._mesh_policy = None
        self._namespace = None
        self._object_type = None
        self._peer_authentication = None
        self._permissions = None
        self._policy = None
        self._quota_spec = None
        self._quota_spec_binding = None
        self._rbac_config = None
        self._request_authentication = None
        self._rule = None
        self._service_entry = None
        self._service_mesh_policy = None
        self._service_mesh_rbac_config = None
        self._service_role = None
        self._service_role_binding = None
        self._sidecar = None
        self._template = None
        self._virtual_service = None
        self._workload_entry = None
        self.discriminator = None
        if adapter is not None:
            self.adapter = adapter
        if attribute_manifest is not None:
            self.attribute_manifest = attribute_manifest
        if authorization_policy is not None:
            self.authorization_policy = authorization_policy
        if cluster_rbac_config is not None:
            self.cluster_rbac_config = cluster_rbac_config
        if destination_rule is not None:
            self.destination_rule = destination_rule
        if envoy_filter is not None:
            self.envoy_filter = envoy_filter
        if gateway is not None:
            self.gateway = gateway
        if handler is not None:
            self.handler = handler
        if http_api_spec is not None:
            self.http_api_spec = http_api_spec
        if http_api_spec_binding is not None:
            self.http_api_spec_binding = http_api_spec_binding
        if instance is not None:
            self.instance = instance
        if istio_validation is not None:
            self.istio_validation = istio_validation
        if mesh_policy is not None:
            self.mesh_policy = mesh_policy
        if namespace is not None:
            self.namespace = namespace
        if object_type is not None:
            self.object_type = object_type
        if peer_authentication is not None:
            self.peer_authentication = peer_authentication
        if permissions is not None:
            self.permissions = permissions
        if policy is not None:
            self.policy = policy
        if quota_spec is not None:
            self.quota_spec = quota_spec
        if quota_spec_binding is not None:
            self.quota_spec_binding = quota_spec_binding
        if rbac_config is not None:
            self.rbac_config = rbac_config
        if request_authentication is not None:
            self.request_authentication = request_authentication
        if rule is not None:
            self.rule = rule
        if service_entry is not None:
            self.service_entry = service_entry
        if service_mesh_policy is not None:
            self.service_mesh_policy = service_mesh_policy
        if service_mesh_rbac_config is not None:
            self.service_mesh_rbac_config = service_mesh_rbac_config
        if service_role is not None:
            self.service_role = service_role
        if service_role_binding is not None:
            self.service_role_binding = service_role_binding
        if sidecar is not None:
            self.sidecar = sidecar
        if template is not None:
            self.template = template
        if virtual_service is not None:
            self.virtual_service = virtual_service
        if workload_entry is not None:
            self.workload_entry = workload_entry

    @property
    def adapter(self):
        """Gets the adapter of this IstioConfigDetails.  # noqa: E501


        :return: The adapter of this IstioConfigDetails.  # noqa: E501
        :rtype: IstioAdapter
        """
        return self._adapter

    @adapter.setter
    def adapter(self, adapter):
        """Sets the adapter of this IstioConfigDetails.


        :param adapter: The adapter of this IstioConfigDetails.  # noqa: E501
        :type: IstioAdapter
        """

        self._adapter = adapter

    @property
    def attribute_manifest(self):
        """Gets the attribute_manifest of this IstioConfigDetails.  # noqa: E501


        :return: The attribute_manifest of this IstioConfigDetails.  # noqa: E501
        :rtype: AttributeManifest
        """
        return self._attribute_manifest

    @attribute_manifest.setter
    def attribute_manifest(self, attribute_manifest):
        """Sets the attribute_manifest of this IstioConfigDetails.


        :param attribute_manifest: The attribute_manifest of this IstioConfigDetails.  # noqa: E501
        :type: AttributeManifest
        """

        self._attribute_manifest = attribute_manifest

    @property
    def authorization_policy(self):
        """Gets the authorization_policy of this IstioConfigDetails.  # noqa: E501


        :return: The authorization_policy of this IstioConfigDetails.  # noqa: E501
        :rtype: AuthorizationPolicy
        """
        return self._authorization_policy

    @authorization_policy.setter
    def authorization_policy(self, authorization_policy):
        """Sets the authorization_policy of this IstioConfigDetails.


        :param authorization_policy: The authorization_policy of this IstioConfigDetails.  # noqa: E501
        :type: AuthorizationPolicy
        """

        self._authorization_policy = authorization_policy

    @property
    def cluster_rbac_config(self):
        """Gets the cluster_rbac_config of this IstioConfigDetails.  # noqa: E501


        :return: The cluster_rbac_config of this IstioConfigDetails.  # noqa: E501
        :rtype: ClusterRbacConfig
        """
        return self._cluster_rbac_config

    @cluster_rbac_config.setter
    def cluster_rbac_config(self, cluster_rbac_config):
        """Sets the cluster_rbac_config of this IstioConfigDetails.


        :param cluster_rbac_config: The cluster_rbac_config of this IstioConfigDetails.  # noqa: E501
        :type: ClusterRbacConfig
        """

        self._cluster_rbac_config = cluster_rbac_config

    @property
    def destination_rule(self):
        """Gets the destination_rule of this IstioConfigDetails.  # noqa: E501


        :return: The destination_rule of this IstioConfigDetails.  # noqa: E501
        :rtype: DestinationRule
        """
        return self._destination_rule

    @destination_rule.setter
    def destination_rule(self, destination_rule):
        """Sets the destination_rule of this IstioConfigDetails.


        :param destination_rule: The destination_rule of this IstioConfigDetails.  # noqa: E501
        :type: DestinationRule
        """

        self._destination_rule = destination_rule

    @property
    def envoy_filter(self):
        """Gets the envoy_filter of this IstioConfigDetails.  # noqa: E501


        :return: The envoy_filter of this IstioConfigDetails.  # noqa: E501
        :rtype: EnvoyFilter
        """
        return self._envoy_filter

    @envoy_filter.setter
    def envoy_filter(self, envoy_filter):
        """Sets the envoy_filter of this IstioConfigDetails.


        :param envoy_filter: The envoy_filter of this IstioConfigDetails.  # noqa: E501
        :type: EnvoyFilter
        """

        self._envoy_filter = envoy_filter

    @property
    def gateway(self):
        """Gets the gateway of this IstioConfigDetails.  # noqa: E501


        :return: The gateway of this IstioConfigDetails.  # noqa: E501
        :rtype: Gateway
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this IstioConfigDetails.


        :param gateway: The gateway of this IstioConfigDetails.  # noqa: E501
        :type: Gateway
        """

        self._gateway = gateway

    @property
    def handler(self):
        """Gets the handler of this IstioConfigDetails.  # noqa: E501


        :return: The handler of this IstioConfigDetails.  # noqa: E501
        :rtype: IstioHandler
        """
        return self._handler

    @handler.setter
    def handler(self, handler):
        """Sets the handler of this IstioConfigDetails.


        :param handler: The handler of this IstioConfigDetails.  # noqa: E501
        :type: IstioHandler
        """

        self._handler = handler

    @property
    def http_api_spec(self):
        """Gets the http_api_spec of this IstioConfigDetails.  # noqa: E501


        :return: The http_api_spec of this IstioConfigDetails.  # noqa: E501
        :rtype: HttpApiSpec
        """
        return self._http_api_spec

    @http_api_spec.setter
    def http_api_spec(self, http_api_spec):
        """Sets the http_api_spec of this IstioConfigDetails.


        :param http_api_spec: The http_api_spec of this IstioConfigDetails.  # noqa: E501
        :type: HttpApiSpec
        """

        self._http_api_spec = http_api_spec

    @property
    def http_api_spec_binding(self):
        """Gets the http_api_spec_binding of this IstioConfigDetails.  # noqa: E501


        :return: The http_api_spec_binding of this IstioConfigDetails.  # noqa: E501
        :rtype: HttpApiSpecBinding
        """
        return self._http_api_spec_binding

    @http_api_spec_binding.setter
    def http_api_spec_binding(self, http_api_spec_binding):
        """Sets the http_api_spec_binding of this IstioConfigDetails.


        :param http_api_spec_binding: The http_api_spec_binding of this IstioConfigDetails.  # noqa: E501
        :type: HttpApiSpecBinding
        """

        self._http_api_spec_binding = http_api_spec_binding

    @property
    def instance(self):
        """Gets the instance of this IstioConfigDetails.  # noqa: E501


        :return: The instance of this IstioConfigDetails.  # noqa: E501
        :rtype: IstioInstance
        """
        return self._instance

    @instance.setter
    def instance(self, instance):
        """Sets the instance of this IstioConfigDetails.


        :param instance: The instance of this IstioConfigDetails.  # noqa: E501
        :type: IstioInstance
        """

        self._instance = instance

    @property
    def istio_validation(self):
        """Gets the istio_validation of this IstioConfigDetails.  # noqa: E501


        :return: The istio_validation of this IstioConfigDetails.  # noqa: E501
        :rtype: IstioValidation
        """
        return self._istio_validation

    @istio_validation.setter
    def istio_validation(self, istio_validation):
        """Sets the istio_validation of this IstioConfigDetails.


        :param istio_validation: The istio_validation of this IstioConfigDetails.  # noqa: E501
        :type: IstioValidation
        """

        self._istio_validation = istio_validation

    @property
    def mesh_policy(self):
        """Gets the mesh_policy of this IstioConfigDetails.  # noqa: E501


        :return: The mesh_policy of this IstioConfigDetails.  # noqa: E501
        :rtype: MeshPolicy
        """
        return self._mesh_policy

    @mesh_policy.setter
    def mesh_policy(self, mesh_policy):
        """Sets the mesh_policy of this IstioConfigDetails.


        :param mesh_policy: The mesh_policy of this IstioConfigDetails.  # noqa: E501
        :type: MeshPolicy
        """

        self._mesh_policy = mesh_policy

    @property
    def namespace(self):
        """Gets the namespace of this IstioConfigDetails.  # noqa: E501


        :return: The namespace of this IstioConfigDetails.  # noqa: E501
        :rtype: Namespace
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this IstioConfigDetails.


        :param namespace: The namespace of this IstioConfigDetails.  # noqa: E501
        :type: Namespace
        """

        self._namespace = namespace

    @property
    def object_type(self):
        """Gets the object_type of this IstioConfigDetails.  # noqa: E501


        :return: The object_type of this IstioConfigDetails.  # noqa: E501
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this IstioConfigDetails.


        :param object_type: The object_type of this IstioConfigDetails.  # noqa: E501
        :type: str
        """

        self._object_type = object_type

    @property
    def peer_authentication(self):
        """Gets the peer_authentication of this IstioConfigDetails.  # noqa: E501


        :return: The peer_authentication of this IstioConfigDetails.  # noqa: E501
        :rtype: PeerAuthentication
        """
        return self._peer_authentication

    @peer_authentication.setter
    def peer_authentication(self, peer_authentication):
        """Sets the peer_authentication of this IstioConfigDetails.


        :param peer_authentication: The peer_authentication of this IstioConfigDetails.  # noqa: E501
        :type: PeerAuthentication
        """

        self._peer_authentication = peer_authentication

    @property
    def permissions(self):
        """Gets the permissions of this IstioConfigDetails.  # noqa: E501


        :return: The permissions of this IstioConfigDetails.  # noqa: E501
        :rtype: ResourcePermissions
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this IstioConfigDetails.


        :param permissions: The permissions of this IstioConfigDetails.  # noqa: E501
        :type: ResourcePermissions
        """

        self._permissions = permissions

    @property
    def policy(self):
        """Gets the policy of this IstioConfigDetails.  # noqa: E501


        :return: The policy of this IstioConfigDetails.  # noqa: E501
        :rtype: Policy
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this IstioConfigDetails.


        :param policy: The policy of this IstioConfigDetails.  # noqa: E501
        :type: Policy
        """

        self._policy = policy

    @property
    def quota_spec(self):
        """Gets the quota_spec of this IstioConfigDetails.  # noqa: E501


        :return: The quota_spec of this IstioConfigDetails.  # noqa: E501
        :rtype: QuotaSpec
        """
        return self._quota_spec

    @quota_spec.setter
    def quota_spec(self, quota_spec):
        """Sets the quota_spec of this IstioConfigDetails.


        :param quota_spec: The quota_spec of this IstioConfigDetails.  # noqa: E501
        :type: QuotaSpec
        """

        self._quota_spec = quota_spec

    @property
    def quota_spec_binding(self):
        """Gets the quota_spec_binding of this IstioConfigDetails.  # noqa: E501


        :return: The quota_spec_binding of this IstioConfigDetails.  # noqa: E501
        :rtype: QuotaSpecBinding
        """
        return self._quota_spec_binding

    @quota_spec_binding.setter
    def quota_spec_binding(self, quota_spec_binding):
        """Sets the quota_spec_binding of this IstioConfigDetails.


        :param quota_spec_binding: The quota_spec_binding of this IstioConfigDetails.  # noqa: E501
        :type: QuotaSpecBinding
        """

        self._quota_spec_binding = quota_spec_binding

    @property
    def rbac_config(self):
        """Gets the rbac_config of this IstioConfigDetails.  # noqa: E501


        :return: The rbac_config of this IstioConfigDetails.  # noqa: E501
        :rtype: RbacConfig
        """
        return self._rbac_config

    @rbac_config.setter
    def rbac_config(self, rbac_config):
        """Sets the rbac_config of this IstioConfigDetails.


        :param rbac_config: The rbac_config of this IstioConfigDetails.  # noqa: E501
        :type: RbacConfig
        """

        self._rbac_config = rbac_config

    @property
    def request_authentication(self):
        """Gets the request_authentication of this IstioConfigDetails.  # noqa: E501


        :return: The request_authentication of this IstioConfigDetails.  # noqa: E501
        :rtype: RequestAuthentication
        """
        return self._request_authentication

    @request_authentication.setter
    def request_authentication(self, request_authentication):
        """Sets the request_authentication of this IstioConfigDetails.


        :param request_authentication: The request_authentication of this IstioConfigDetails.  # noqa: E501
        :type: RequestAuthentication
        """

        self._request_authentication = request_authentication

    @property
    def rule(self):
        """Gets the rule of this IstioConfigDetails.  # noqa: E501


        :return: The rule of this IstioConfigDetails.  # noqa: E501
        :rtype: IstioRule
        """
        return self._rule

    @rule.setter
    def rule(self, rule):
        """Sets the rule of this IstioConfigDetails.


        :param rule: The rule of this IstioConfigDetails.  # noqa: E501
        :type: IstioRule
        """

        self._rule = rule

    @property
    def service_entry(self):
        """Gets the service_entry of this IstioConfigDetails.  # noqa: E501


        :return: The service_entry of this IstioConfigDetails.  # noqa: E501
        :rtype: ServiceEntry
        """
        return self._service_entry

    @service_entry.setter
    def service_entry(self, service_entry):
        """Sets the service_entry of this IstioConfigDetails.


        :param service_entry: The service_entry of this IstioConfigDetails.  # noqa: E501
        :type: ServiceEntry
        """

        self._service_entry = service_entry

    @property
    def service_mesh_policy(self):
        """Gets the service_mesh_policy of this IstioConfigDetails.  # noqa: E501


        :return: The service_mesh_policy of this IstioConfigDetails.  # noqa: E501
        :rtype: ServiceMeshPolicy
        """
        return self._service_mesh_policy

    @service_mesh_policy.setter
    def service_mesh_policy(self, service_mesh_policy):
        """Sets the service_mesh_policy of this IstioConfigDetails.


        :param service_mesh_policy: The service_mesh_policy of this IstioConfigDetails.  # noqa: E501
        :type: ServiceMeshPolicy
        """

        self._service_mesh_policy = service_mesh_policy

    @property
    def service_mesh_rbac_config(self):
        """Gets the service_mesh_rbac_config of this IstioConfigDetails.  # noqa: E501


        :return: The service_mesh_rbac_config of this IstioConfigDetails.  # noqa: E501
        :rtype: ServiceMeshRbacConfig
        """
        return self._service_mesh_rbac_config

    @service_mesh_rbac_config.setter
    def service_mesh_rbac_config(self, service_mesh_rbac_config):
        """Sets the service_mesh_rbac_config of this IstioConfigDetails.


        :param service_mesh_rbac_config: The service_mesh_rbac_config of this IstioConfigDetails.  # noqa: E501
        :type: ServiceMeshRbacConfig
        """

        self._service_mesh_rbac_config = service_mesh_rbac_config

    @property
    def service_role(self):
        """Gets the service_role of this IstioConfigDetails.  # noqa: E501


        :return: The service_role of this IstioConfigDetails.  # noqa: E501
        :rtype: ServiceRole
        """
        return self._service_role

    @service_role.setter
    def service_role(self, service_role):
        """Sets the service_role of this IstioConfigDetails.


        :param service_role: The service_role of this IstioConfigDetails.  # noqa: E501
        :type: ServiceRole
        """

        self._service_role = service_role

    @property
    def service_role_binding(self):
        """Gets the service_role_binding of this IstioConfigDetails.  # noqa: E501


        :return: The service_role_binding of this IstioConfigDetails.  # noqa: E501
        :rtype: ServiceRoleBinding
        """
        return self._service_role_binding

    @service_role_binding.setter
    def service_role_binding(self, service_role_binding):
        """Sets the service_role_binding of this IstioConfigDetails.


        :param service_role_binding: The service_role_binding of this IstioConfigDetails.  # noqa: E501
        :type: ServiceRoleBinding
        """

        self._service_role_binding = service_role_binding

    @property
    def sidecar(self):
        """Gets the sidecar of this IstioConfigDetails.  # noqa: E501


        :return: The sidecar of this IstioConfigDetails.  # noqa: E501
        :rtype: Sidecar
        """
        return self._sidecar

    @sidecar.setter
    def sidecar(self, sidecar):
        """Sets the sidecar of this IstioConfigDetails.


        :param sidecar: The sidecar of this IstioConfigDetails.  # noqa: E501
        :type: Sidecar
        """

        self._sidecar = sidecar

    @property
    def template(self):
        """Gets the template of this IstioConfigDetails.  # noqa: E501


        :return: The template of this IstioConfigDetails.  # noqa: E501
        :rtype: IstioTemplate
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this IstioConfigDetails.


        :param template: The template of this IstioConfigDetails.  # noqa: E501
        :type: IstioTemplate
        """

        self._template = template

    @property
    def virtual_service(self):
        """Gets the virtual_service of this IstioConfigDetails.  # noqa: E501


        :return: The virtual_service of this IstioConfigDetails.  # noqa: E501
        :rtype: VirtualService
        """
        return self._virtual_service

    @virtual_service.setter
    def virtual_service(self, virtual_service):
        """Sets the virtual_service of this IstioConfigDetails.


        :param virtual_service: The virtual_service of this IstioConfigDetails.  # noqa: E501
        :type: VirtualService
        """

        self._virtual_service = virtual_service

    @property
    def workload_entry(self):
        """Gets the workload_entry of this IstioConfigDetails.  # noqa: E501


        :return: The workload_entry of this IstioConfigDetails.  # noqa: E501
        :rtype: WorkloadEntry
        """
        return self._workload_entry

    @workload_entry.setter
    def workload_entry(self, workload_entry):
        """Sets the workload_entry of this IstioConfigDetails.


        :param workload_entry: The workload_entry of this IstioConfigDetails.  # noqa: E501
        :type: WorkloadEntry
        """

        self._workload_entry = workload_entry

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IstioConfigDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IstioConfigDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.service_binding_resource import ServiceBindingResource  # noqa: F401,E501


class ServiceBindingParam(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bind_resource': 'ServiceBindingResource',
        'description': 'str',
        'id': 'str',
        'name': 'str',
        'parameters': 'dict(str, object)',
        'svc_class_id': 'str'
    }

    attribute_map = {
        'bind_resource': 'bindResource',
        'description': 'description',
        'id': 'id',
        'name': 'name',
        'parameters': 'parameters',
        'svc_class_id': 'svcClassId'
    }

    def __init__(self, bind_resource=None, description=None, id=None, name=None, parameters=None, svc_class_id=None):  # noqa: E501
        """ServiceBindingParam - a model defined in Swagger"""  # noqa: E501
        self._bind_resource = None
        self._description = None
        self._id = None
        self._name = None
        self._parameters = None
        self._svc_class_id = None
        self.discriminator = None
        if bind_resource is not None:
            self.bind_resource = bind_resource
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        self.name = name
        if parameters is not None:
            self.parameters = parameters
        self.svc_class_id = svc_class_id

    @property
    def bind_resource(self):
        """Gets the bind_resource of this ServiceBindingParam.  # noqa: E501


        :return: The bind_resource of this ServiceBindingParam.  # noqa: E501
        :rtype: ServiceBindingResource
        """
        return self._bind_resource

    @bind_resource.setter
    def bind_resource(self, bind_resource):
        """Sets the bind_resource of this ServiceBindingParam.


        :param bind_resource: The bind_resource of this ServiceBindingParam.  # noqa: E501
        :type: ServiceBindingResource
        """

        self._bind_resource = bind_resource

    @property
    def description(self):
        """Gets the description of this ServiceBindingParam.  # noqa: E501


        :return: The description of this ServiceBindingParam.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ServiceBindingParam.


        :param description: The description of this ServiceBindingParam.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this ServiceBindingParam.  # noqa: E501


        :return: The id of this ServiceBindingParam.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServiceBindingParam.


        :param id: The id of this ServiceBindingParam.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ServiceBindingParam.  # noqa: E501


        :return: The name of this ServiceBindingParam.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServiceBindingParam.


        :param name: The name of this ServiceBindingParam.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def parameters(self):
        """Gets the parameters of this ServiceBindingParam.  # noqa: E501


        :return: The parameters of this ServiceBindingParam.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this ServiceBindingParam.


        :param parameters: The parameters of this ServiceBindingParam.  # noqa: E501
        :type: dict(str, object)
        """

        self._parameters = parameters

    @property
    def svc_class_id(self):
        """Gets the svc_class_id of this ServiceBindingParam.  # noqa: E501


        :return: The svc_class_id of this ServiceBindingParam.  # noqa: E501
        :rtype: str
        """
        return self._svc_class_id

    @svc_class_id.setter
    def svc_class_id(self, svc_class_id):
        """Sets the svc_class_id of this ServiceBindingParam.


        :param svc_class_id: The svc_class_id of this ServiceBindingParam.  # noqa: E501
        :type: str
        """
        if svc_class_id is None:
            raise ValueError("Invalid value for `svc_class_id`, must not be `None`")  # noqa: E501

        self._svc_class_id = svc_class_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServiceBindingParam, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceBindingParam):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.application import Application  # noqa: F401,E501
from kps_api.models.category import Category  # noqa: F401,E501
from kps_api.models.cloud_creds import CloudCreds  # noqa: F401,E501
from kps_api.models.connector_instance_inventory import ConnectorInstanceInventory  # noqa: F401,E501
from kps_api.models.container_registry import ContainerRegistry  # noqa: F401,E501
from kps_api.models.data_source import DataSource  # noqa: F401,E501
from kps_api.models.data_stream import DataStream  # noqa: F401,E501
from kps_api.models.log_collector import LogCollector  # noqa: F401,E501
from kps_api.models.ml_model import MLModel  # noqa: F401,E501
from kps_api.models.project import Project  # noqa: F401,E501
from kps_api.models.project_service import ProjectService  # noqa: F401,E501
from kps_api.models.script import Script  # noqa: F401,E501
from kps_api.models.script_runtime import ScriptRuntime  # noqa: F401,E501
from kps_api.models.service_binding import ServiceBinding  # noqa: F401,E501
from kps_api.models.service_instance import ServiceInstance  # noqa: F401,E501
from kps_api.models.software_update_service_domain import SoftwareUpdateServiceDomain  # noqa: F401,E501


class EdgeInventoryDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'applications': 'list[Application]',
        'categories': 'list[Category]',
        'cloud_profiles': 'list[CloudCreds]',
        'connector_instances': 'list[ConnectorInstanceInventory]',
        'container_registries': 'list[ContainerRegistry]',
        'data_pipelines': 'list[DataStream]',
        'data_sources': 'list[DataSource]',
        'functions': 'list[Script]',
        'log_collectors': 'list[LogCollector]',
        'ml_models': 'list[MLModel]',
        'project_services': 'list[ProjectService]',
        'projects': 'list[Project]',
        'runtime_environments': 'list[ScriptRuntime]',
        'software_updates': 'list[SoftwareUpdateServiceDomain]',
        'svc_bindings': 'list[ServiceBinding]',
        'svc_instances': 'list[ServiceInstance]'
    }

    attribute_map = {
        'applications': 'Applications',
        'categories': 'Categories',
        'cloud_profiles': 'CloudProfiles',
        'connector_instances': 'ConnectorInstances',
        'container_registries': 'ContainerRegistries',
        'data_pipelines': 'DataPipelines',
        'data_sources': 'DataSources',
        'functions': 'Functions',
        'log_collectors': 'LogCollectors',
        'ml_models': 'MLModels',
        'project_services': 'ProjectServices',
        'projects': 'Projects',
        'runtime_environments': 'RuntimeEnvironments',
        'software_updates': 'SoftwareUpdates',
        'svc_bindings': 'SvcBindings',
        'svc_instances': 'SvcInstances'
    }

    def __init__(self, applications=None, categories=None, cloud_profiles=None, connector_instances=None, container_registries=None, data_pipelines=None, data_sources=None, functions=None, log_collectors=None, ml_models=None, project_services=None, projects=None, runtime_environments=None, software_updates=None, svc_bindings=None, svc_instances=None):  # noqa: E501
        """EdgeInventoryDetails - a model defined in Swagger"""  # noqa: E501
        self._applications = None
        self._categories = None
        self._cloud_profiles = None
        self._connector_instances = None
        self._container_registries = None
        self._data_pipelines = None
        self._data_sources = None
        self._functions = None
        self._log_collectors = None
        self._ml_models = None
        self._project_services = None
        self._projects = None
        self._runtime_environments = None
        self._software_updates = None
        self._svc_bindings = None
        self._svc_instances = None
        self.discriminator = None
        if applications is not None:
            self.applications = applications
        if categories is not None:
            self.categories = categories
        if cloud_profiles is not None:
            self.cloud_profiles = cloud_profiles
        if connector_instances is not None:
            self.connector_instances = connector_instances
        if container_registries is not None:
            self.container_registries = container_registries
        if data_pipelines is not None:
            self.data_pipelines = data_pipelines
        if data_sources is not None:
            self.data_sources = data_sources
        if functions is not None:
            self.functions = functions
        if log_collectors is not None:
            self.log_collectors = log_collectors
        if ml_models is not None:
            self.ml_models = ml_models
        if project_services is not None:
            self.project_services = project_services
        if projects is not None:
            self.projects = projects
        if runtime_environments is not None:
            self.runtime_environments = runtime_environments
        if software_updates is not None:
            self.software_updates = software_updates
        if svc_bindings is not None:
            self.svc_bindings = svc_bindings
        if svc_instances is not None:
            self.svc_instances = svc_instances

    @property
    def applications(self):
        """Gets the applications of this EdgeInventoryDetails.  # noqa: E501


        :return: The applications of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[Application]
        """
        return self._applications

    @applications.setter
    def applications(self, applications):
        """Sets the applications of this EdgeInventoryDetails.


        :param applications: The applications of this EdgeInventoryDetails.  # noqa: E501
        :type: list[Application]
        """

        self._applications = applications

    @property
    def categories(self):
        """Gets the categories of this EdgeInventoryDetails.  # noqa: E501


        :return: The categories of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[Category]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this EdgeInventoryDetails.


        :param categories: The categories of this EdgeInventoryDetails.  # noqa: E501
        :type: list[Category]
        """

        self._categories = categories

    @property
    def cloud_profiles(self):
        """Gets the cloud_profiles of this EdgeInventoryDetails.  # noqa: E501


        :return: The cloud_profiles of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[CloudCreds]
        """
        return self._cloud_profiles

    @cloud_profiles.setter
    def cloud_profiles(self, cloud_profiles):
        """Sets the cloud_profiles of this EdgeInventoryDetails.


        :param cloud_profiles: The cloud_profiles of this EdgeInventoryDetails.  # noqa: E501
        :type: list[CloudCreds]
        """

        self._cloud_profiles = cloud_profiles

    @property
    def connector_instances(self):
        """Gets the connector_instances of this EdgeInventoryDetails.  # noqa: E501


        :return: The connector_instances of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[ConnectorInstanceInventory]
        """
        return self._connector_instances

    @connector_instances.setter
    def connector_instances(self, connector_instances):
        """Sets the connector_instances of this EdgeInventoryDetails.


        :param connector_instances: The connector_instances of this EdgeInventoryDetails.  # noqa: E501
        :type: list[ConnectorInstanceInventory]
        """

        self._connector_instances = connector_instances

    @property
    def container_registries(self):
        """Gets the container_registries of this EdgeInventoryDetails.  # noqa: E501


        :return: The container_registries of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[ContainerRegistry]
        """
        return self._container_registries

    @container_registries.setter
    def container_registries(self, container_registries):
        """Sets the container_registries of this EdgeInventoryDetails.


        :param container_registries: The container_registries of this EdgeInventoryDetails.  # noqa: E501
        :type: list[ContainerRegistry]
        """

        self._container_registries = container_registries

    @property
    def data_pipelines(self):
        """Gets the data_pipelines of this EdgeInventoryDetails.  # noqa: E501


        :return: The data_pipelines of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[DataStream]
        """
        return self._data_pipelines

    @data_pipelines.setter
    def data_pipelines(self, data_pipelines):
        """Sets the data_pipelines of this EdgeInventoryDetails.


        :param data_pipelines: The data_pipelines of this EdgeInventoryDetails.  # noqa: E501
        :type: list[DataStream]
        """

        self._data_pipelines = data_pipelines

    @property
    def data_sources(self):
        """Gets the data_sources of this EdgeInventoryDetails.  # noqa: E501


        :return: The data_sources of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[DataSource]
        """
        return self._data_sources

    @data_sources.setter
    def data_sources(self, data_sources):
        """Sets the data_sources of this EdgeInventoryDetails.


        :param data_sources: The data_sources of this EdgeInventoryDetails.  # noqa: E501
        :type: list[DataSource]
        """

        self._data_sources = data_sources

    @property
    def functions(self):
        """Gets the functions of this EdgeInventoryDetails.  # noqa: E501


        :return: The functions of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[Script]
        """
        return self._functions

    @functions.setter
    def functions(self, functions):
        """Sets the functions of this EdgeInventoryDetails.


        :param functions: The functions of this EdgeInventoryDetails.  # noqa: E501
        :type: list[Script]
        """

        self._functions = functions

    @property
    def log_collectors(self):
        """Gets the log_collectors of this EdgeInventoryDetails.  # noqa: E501


        :return: The log_collectors of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[LogCollector]
        """
        return self._log_collectors

    @log_collectors.setter
    def log_collectors(self, log_collectors):
        """Sets the log_collectors of this EdgeInventoryDetails.


        :param log_collectors: The log_collectors of this EdgeInventoryDetails.  # noqa: E501
        :type: list[LogCollector]
        """

        self._log_collectors = log_collectors

    @property
    def ml_models(self):
        """Gets the ml_models of this EdgeInventoryDetails.  # noqa: E501


        :return: The ml_models of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[MLModel]
        """
        return self._ml_models

    @ml_models.setter
    def ml_models(self, ml_models):
        """Sets the ml_models of this EdgeInventoryDetails.


        :param ml_models: The ml_models of this EdgeInventoryDetails.  # noqa: E501
        :type: list[MLModel]
        """

        self._ml_models = ml_models

    @property
    def project_services(self):
        """Gets the project_services of this EdgeInventoryDetails.  # noqa: E501


        :return: The project_services of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[ProjectService]
        """
        return self._project_services

    @project_services.setter
    def project_services(self, project_services):
        """Sets the project_services of this EdgeInventoryDetails.


        :param project_services: The project_services of this EdgeInventoryDetails.  # noqa: E501
        :type: list[ProjectService]
        """

        self._project_services = project_services

    @property
    def projects(self):
        """Gets the projects of this EdgeInventoryDetails.  # noqa: E501


        :return: The projects of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[Project]
        """
        return self._projects

    @projects.setter
    def projects(self, projects):
        """Sets the projects of this EdgeInventoryDetails.


        :param projects: The projects of this EdgeInventoryDetails.  # noqa: E501
        :type: list[Project]
        """

        self._projects = projects

    @property
    def runtime_environments(self):
        """Gets the runtime_environments of this EdgeInventoryDetails.  # noqa: E501


        :return: The runtime_environments of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[ScriptRuntime]
        """
        return self._runtime_environments

    @runtime_environments.setter
    def runtime_environments(self, runtime_environments):
        """Sets the runtime_environments of this EdgeInventoryDetails.


        :param runtime_environments: The runtime_environments of this EdgeInventoryDetails.  # noqa: E501
        :type: list[ScriptRuntime]
        """

        self._runtime_environments = runtime_environments

    @property
    def software_updates(self):
        """Gets the software_updates of this EdgeInventoryDetails.  # noqa: E501


        :return: The software_updates of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[SoftwareUpdateServiceDomain]
        """
        return self._software_updates

    @software_updates.setter
    def software_updates(self, software_updates):
        """Sets the software_updates of this EdgeInventoryDetails.


        :param software_updates: The software_updates of this EdgeInventoryDetails.  # noqa: E501
        :type: list[SoftwareUpdateServiceDomain]
        """

        self._software_updates = software_updates

    @property
    def svc_bindings(self):
        """Gets the svc_bindings of this EdgeInventoryDetails.  # noqa: E501


        :return: The svc_bindings of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[ServiceBinding]
        """
        return self._svc_bindings

    @svc_bindings.setter
    def svc_bindings(self, svc_bindings):
        """Sets the svc_bindings of this EdgeInventoryDetails.


        :param svc_bindings: The svc_bindings of this EdgeInventoryDetails.  # noqa: E501
        :type: list[ServiceBinding]
        """

        self._svc_bindings = svc_bindings

    @property
    def svc_instances(self):
        """Gets the svc_instances of this EdgeInventoryDetails.  # noqa: E501


        :return: The svc_instances of this EdgeInventoryDetails.  # noqa: E501
        :rtype: list[ServiceInstance]
        """
        return self._svc_instances

    @svc_instances.setter
    def svc_instances(self, svc_instances):
        """Sets the svc_instances of this EdgeInventoryDetails.


        :param svc_instances: The svc_instances of this EdgeInventoryDetails.  # noqa: E501
        :type: list[ServiceInstance]
        """

        self._svc_instances = svc_instances

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EdgeInventoryDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EdgeInventoryDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AIInferencingRuntime(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'accelerator_device': 'str',
        'framework_type': 'str'
    }

    attribute_map = {
        'accelerator_device': 'AcceleratorDevice',
        'framework_type': 'FrameworkType'
    }

    def __init__(self, accelerator_device=None, framework_type=None):  # noqa: E501
        """AIInferencingRuntime - a model defined in Swagger"""  # noqa: E501
        self._accelerator_device = None
        self._framework_type = None
        self.discriminator = None
        if accelerator_device is not None:
            self.accelerator_device = accelerator_device
        if framework_type is not None:
            self.framework_type = framework_type

    @property
    def accelerator_device(self):
        """Gets the accelerator_device of this AIInferencingRuntime.  # noqa: E501


        :return: The accelerator_device of this AIInferencingRuntime.  # noqa: E501
        :rtype: str
        """
        return self._accelerator_device

    @accelerator_device.setter
    def accelerator_device(self, accelerator_device):
        """Sets the accelerator_device of this AIInferencingRuntime.


        :param accelerator_device: The accelerator_device of this AIInferencingRuntime.  # noqa: E501
        :type: str
        """
        allowed_values = ["CPU", "GPU"]  # noqa: E501
        if accelerator_device not in allowed_values:
            raise ValueError(
                "Invalid value for `accelerator_device` ({0}), must be one of {1}"  # noqa: E501
                .format(accelerator_device, allowed_values)
            )

        self._accelerator_device = accelerator_device

    @property
    def framework_type(self):
        """Gets the framework_type of this AIInferencingRuntime.  # noqa: E501


        :return: The framework_type of this AIInferencingRuntime.  # noqa: E501
        :rtype: str
        """
        return self._framework_type

    @framework_type.setter
    def framework_type(self, framework_type):
        """Sets the framework_type of this AIInferencingRuntime.


        :param framework_type: The framework_type of this AIInferencingRuntime.  # noqa: E501
        :type: str
        """
        allowed_values = ["TensorFlow1.13.1", "TensorFlow2.1.0"]  # noqa: E501
        if framework_type not in allowed_values:
            raise ValueError(
                "Invalid value for `framework_type` ({0}), must be one of {1}"  # noqa: E501
                .format(framework_type, allowed_values)
            )

        self._framework_type = framework_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AIInferencingRuntime, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AIInferencingRuntime):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.software_update_batch_type import SoftwareUpdateBatchType  # noqa: F401,E501
from kps_api.models.software_update_state_type import SoftwareUpdateStateType  # noqa: F401,E501


class SoftwareUpdateBatch(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'eta': 'int',
        'id': 'str',
        'progress': 'int',
        'release': 'str',
        'state': 'SoftwareUpdateStateType',
        'stats': 'dict(str, int)',
        'type': 'SoftwareUpdateBatchType',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'eta': 'eta',
        'id': 'id',
        'progress': 'progress',
        'release': 'release',
        'state': 'state',
        'stats': 'stats',
        'type': 'type',
        'updated_at': 'updatedAt'
    }

    def __init__(self, created_at=None, eta=None, id=None, progress=None, release=None, state=None, stats=None, type=None, updated_at=None):  # noqa: E501
        """SoftwareUpdateBatch - a model defined in Swagger"""  # noqa: E501
        self._created_at = None
        self._eta = None
        self._id = None
        self._progress = None
        self._release = None
        self._state = None
        self._stats = None
        self._type = None
        self._updated_at = None
        self.discriminator = None
        if created_at is not None:
            self.created_at = created_at
        if eta is not None:
            self.eta = eta
        self.id = id
        if progress is not None:
            self.progress = progress
        self.release = release
        if state is not None:
            self.state = state
        if stats is not None:
            self.stats = stats
        self.type = type
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this SoftwareUpdateBatch.  # noqa: E501

        Created timestamp  # noqa: E501

        :return: The created_at of this SoftwareUpdateBatch.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SoftwareUpdateBatch.

        Created timestamp  # noqa: E501

        :param created_at: The created_at of this SoftwareUpdateBatch.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def eta(self):
        """Gets the eta of this SoftwareUpdateBatch.  # noqa: E501

        ETA in mins  # noqa: E501

        :return: The eta of this SoftwareUpdateBatch.  # noqa: E501
        :rtype: int
        """
        return self._eta

    @eta.setter
    def eta(self, eta):
        """Sets the eta of this SoftwareUpdateBatch.

        ETA in mins  # noqa: E501

        :param eta: The eta of this SoftwareUpdateBatch.  # noqa: E501
        :type: int
        """

        self._eta = eta

    @property
    def id(self):
        """Gets the id of this SoftwareUpdateBatch.  # noqa: E501


        :return: The id of this SoftwareUpdateBatch.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SoftwareUpdateBatch.


        :param id: The id of this SoftwareUpdateBatch.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def progress(self):
        """Gets the progress of this SoftwareUpdateBatch.  # noqa: E501

        Progress in percentage  # noqa: E501

        :return: The progress of this SoftwareUpdateBatch.  # noqa: E501
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this SoftwareUpdateBatch.

        Progress in percentage  # noqa: E501

        :param progress: The progress of this SoftwareUpdateBatch.  # noqa: E501
        :type: int
        """

        self._progress = progress

    @property
    def release(self):
        """Gets the release of this SoftwareUpdateBatch.  # noqa: E501


        :return: The release of this SoftwareUpdateBatch.  # noqa: E501
        :rtype: str
        """
        return self._release

    @release.setter
    def release(self, release):
        """Sets the release of this SoftwareUpdateBatch.


        :param release: The release of this SoftwareUpdateBatch.  # noqa: E501
        :type: str
        """
        if release is None:
            raise ValueError("Invalid value for `release`, must not be `None`")  # noqa: E501

        self._release = release

    @property
    def state(self):
        """Gets the state of this SoftwareUpdateBatch.  # noqa: E501


        :return: The state of this SoftwareUpdateBatch.  # noqa: E501
        :rtype: SoftwareUpdateStateType
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SoftwareUpdateBatch.


        :param state: The state of this SoftwareUpdateBatch.  # noqa: E501
        :type: SoftwareUpdateStateType
        """

        self._state = state

    @property
    def stats(self):
        """Gets the stats of this SoftwareUpdateBatch.  # noqa: E501

        Count for each stat type  # noqa: E501

        :return: The stats of this SoftwareUpdateBatch.  # noqa: E501
        :rtype: dict(str, int)
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this SoftwareUpdateBatch.

        Count for each stat type  # noqa: E501

        :param stats: The stats of this SoftwareUpdateBatch.  # noqa: E501
        :type: dict(str, int)
        """

        self._stats = stats

    @property
    def type(self):
        """Gets the type of this SoftwareUpdateBatch.  # noqa: E501


        :return: The type of this SoftwareUpdateBatch.  # noqa: E501
        :rtype: SoftwareUpdateBatchType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SoftwareUpdateBatch.


        :param type: The type of this SoftwareUpdateBatch.  # noqa: E501
        :type: SoftwareUpdateBatchType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def updated_at(self):
        """Gets the updated_at of this SoftwareUpdateBatch.  # noqa: E501

        Record updated timestamp  # noqa: E501

        :return: The updated_at of this SoftwareUpdateBatch.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SoftwareUpdateBatch.

        Record updated timestamp  # noqa: E501

        :param updated_at: The updated_at of this SoftwareUpdateBatch.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SoftwareUpdateBatch, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SoftwareUpdateBatch):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.audit_log_v2_multiple_values import AuditLogV2MultipleValues  # noqa: F401,E501


class AuditLogV2Filter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_time': 'datetime',
        'from_document': 'int',
        'group_by': 'str',
        'page_size': 'int',
        'scopes': 'list[str]',
        'start_time': 'datetime',
        'terms_key_value': 'dict(str, AuditLogV2MultipleValues)'
    }

    attribute_map = {
        'end_time': 'endTime',
        'from_document': 'fromDocument',
        'group_by': 'groupBy',
        'page_size': 'pageSize',
        'scopes': 'scopes',
        'start_time': 'startTime',
        'terms_key_value': 'termsKeyValue'
    }

    def __init__(self, end_time=None, from_document=None, group_by=None, page_size=None, scopes=None, start_time=None, terms_key_value=None):  # noqa: E501
        """AuditLogV2Filter - a model defined in Swagger"""  # noqa: E501
        self._end_time = None
        self._from_document = None
        self._group_by = None
        self._page_size = None
        self._scopes = None
        self._start_time = None
        self._terms_key_value = None
        self.discriminator = None
        if end_time is not None:
            self.end_time = end_time
        if from_document is not None:
            self.from_document = from_document
        if group_by is not None:
            self.group_by = group_by
        if page_size is not None:
            self.page_size = page_size
        if scopes is not None:
            self.scopes = scopes
        if start_time is not None:
            self.start_time = start_time
        self.terms_key_value = terms_key_value

    @property
    def end_time(self):
        """Gets the end_time of this AuditLogV2Filter.  # noqa: E501

        Search for events by this earlier timestamp (inclusive).  # noqa: E501

        :return: The end_time of this AuditLogV2Filter.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this AuditLogV2Filter.

        Search for events by this earlier timestamp (inclusive).  # noqa: E501

        :param end_time: The end_time of this AuditLogV2Filter.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def from_document(self):
        """Gets the from_document of this AuditLogV2Filter.  # noqa: E501


        :return: The from_document of this AuditLogV2Filter.  # noqa: E501
        :rtype: int
        """
        return self._from_document

    @from_document.setter
    def from_document(self, from_document):
        """Sets the from_document of this AuditLogV2Filter.


        :param from_document: The from_document of this AuditLogV2Filter.  # noqa: E501
        :type: int
        """

        self._from_document = from_document

    @property
    def group_by(self):
        """Gets the group_by of this AuditLogV2Filter.  # noqa: E501


        :return: The group_by of this AuditLogV2Filter.  # noqa: E501
        :rtype: str
        """
        return self._group_by

    @group_by.setter
    def group_by(self, group_by):
        """Sets the group_by of this AuditLogV2Filter.


        :param group_by: The group_by of this AuditLogV2Filter.  # noqa: E501
        :type: str
        """

        self._group_by = group_by

    @property
    def page_size(self):
        """Gets the page_size of this AuditLogV2Filter.  # noqa: E501


        :return: The page_size of this AuditLogV2Filter.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this AuditLogV2Filter.


        :param page_size: The page_size of this AuditLogV2Filter.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def scopes(self):
        """Gets the scopes of this AuditLogV2Filter.  # noqa: E501


        :return: The scopes of this AuditLogV2Filter.  # noqa: E501
        :rtype: list[str]
        """
        return self._scopes

    @scopes.setter
    def scopes(self, scopes):
        """Sets the scopes of this AuditLogV2Filter.


        :param scopes: The scopes of this AuditLogV2Filter.  # noqa: E501
        :type: list[str]
        """

        self._scopes = scopes

    @property
    def start_time(self):
        """Gets the start_time of this AuditLogV2Filter.  # noqa: E501

        Search for events by this later timestamp (inclusive)  # noqa: E501

        :return: The start_time of this AuditLogV2Filter.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this AuditLogV2Filter.

        Search for events by this later timestamp (inclusive)  # noqa: E501

        :param start_time: The start_time of this AuditLogV2Filter.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def terms_key_value(self):
        """Gets the terms_key_value of this AuditLogV2Filter.  # noqa: E501

        TenantID must be provided in order to search audit logs  # noqa: E501

        :return: The terms_key_value of this AuditLogV2Filter.  # noqa: E501
        :rtype: dict(str, AuditLogV2MultipleValues)
        """
        return self._terms_key_value

    @terms_key_value.setter
    def terms_key_value(self, terms_key_value):
        """Sets the terms_key_value of this AuditLogV2Filter.

        TenantID must be provided in order to search audit logs  # noqa: E501

        :param terms_key_value: The terms_key_value of this AuditLogV2Filter.  # noqa: E501
        :type: dict(str, AuditLogV2MultipleValues)
        """
        if terms_key_value is None:
            raise ValueError("Invalid value for `terms_key_value`, must not be `None`")  # noqa: E501

        self._terms_key_value = terms_key_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AuditLogV2Filter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogV2Filter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.aggregation import Aggregation  # noqa: F401,E501
from kps_api.models.chart import Chart  # noqa: F401,E501
from kps_api.models.external_link import ExternalLink  # noqa: F401,E501


class MonitoringDashboard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aggregations': 'list[Aggregation]',
        'charts': 'list[Chart]',
        'external_links': 'list[ExternalLink]',
        'title': 'str'
    }

    attribute_map = {
        'aggregations': 'aggregations',
        'charts': 'charts',
        'external_links': 'externalLinks',
        'title': 'title'
    }

    def __init__(self, aggregations=None, charts=None, external_links=None, title=None):  # noqa: E501
        """MonitoringDashboard - a model defined in Swagger"""  # noqa: E501
        self._aggregations = None
        self._charts = None
        self._external_links = None
        self._title = None
        self.discriminator = None
        if aggregations is not None:
            self.aggregations = aggregations
        if charts is not None:
            self.charts = charts
        if external_links is not None:
            self.external_links = external_links
        if title is not None:
            self.title = title

    @property
    def aggregations(self):
        """Gets the aggregations of this MonitoringDashboard.  # noqa: E501


        :return: The aggregations of this MonitoringDashboard.  # noqa: E501
        :rtype: list[Aggregation]
        """
        return self._aggregations

    @aggregations.setter
    def aggregations(self, aggregations):
        """Sets the aggregations of this MonitoringDashboard.


        :param aggregations: The aggregations of this MonitoringDashboard.  # noqa: E501
        :type: list[Aggregation]
        """

        self._aggregations = aggregations

    @property
    def charts(self):
        """Gets the charts of this MonitoringDashboard.  # noqa: E501


        :return: The charts of this MonitoringDashboard.  # noqa: E501
        :rtype: list[Chart]
        """
        return self._charts

    @charts.setter
    def charts(self, charts):
        """Sets the charts of this MonitoringDashboard.


        :param charts: The charts of this MonitoringDashboard.  # noqa: E501
        :type: list[Chart]
        """

        self._charts = charts

    @property
    def external_links(self):
        """Gets the external_links of this MonitoringDashboard.  # noqa: E501


        :return: The external_links of this MonitoringDashboard.  # noqa: E501
        :rtype: list[ExternalLink]
        """
        return self._external_links

    @external_links.setter
    def external_links(self, external_links):
        """Sets the external_links of this MonitoringDashboard.


        :param external_links: The external_links of this MonitoringDashboard.  # noqa: E501
        :type: list[ExternalLink]
        """

        self._external_links = external_links

    @property
    def title(self):
        """Gets the title of this MonitoringDashboard.  # noqa: E501


        :return: The title of this MonitoringDashboard.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this MonitoringDashboard.


        :param title: The title of this MonitoringDashboard.  # noqa: E501
        :type: str
        """

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MonitoringDashboard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MonitoringDashboard):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.additional_item import AdditionalItem  # noqa: F401,E501
from kps_api.models.destination_rules import DestinationRules  # noqa: F401,E501
from kps_api.models.endpoints import Endpoints  # noqa: F401,E501
from kps_api.models.istio_validations import IstioValidations  # noqa: F401,E501
from kps_api.models.mtls_status import MTLSStatus  # noqa: F401,E501
from kps_api.models.service import Service  # noqa: F401,E501
from kps_api.models.service_health import ServiceHealth  # noqa: F401,E501
from kps_api.models.virtual_services import VirtualServices  # noqa: F401,E501
from kps_api.models.workload_overviews import WorkloadOverviews  # noqa: F401,E501


class ServiceDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_details': 'list[AdditionalItem]',
        'destination_rules': 'DestinationRules',
        'endpoints': 'Endpoints',
        'health': 'ServiceHealth',
        'istio_sidecar': 'bool',
        'namespace_mtls': 'MTLSStatus',
        'service': 'Service',
        'validations': 'IstioValidations',
        'virtual_services': 'VirtualServices',
        'workloads': 'WorkloadOverviews'
    }

    attribute_map = {
        'additional_details': 'additionalDetails',
        'destination_rules': 'destinationRules',
        'endpoints': 'endpoints',
        'health': 'health',
        'istio_sidecar': 'istioSidecar',
        'namespace_mtls': 'namespaceMTLS',
        'service': 'service',
        'validations': 'validations',
        'virtual_services': 'virtualServices',
        'workloads': 'workloads'
    }

    def __init__(self, additional_details=None, destination_rules=None, endpoints=None, health=None, istio_sidecar=None, namespace_mtls=None, service=None, validations=None, virtual_services=None, workloads=None):  # noqa: E501
        """ServiceDetails - a model defined in Swagger"""  # noqa: E501
        self._additional_details = None
        self._destination_rules = None
        self._endpoints = None
        self._health = None
        self._istio_sidecar = None
        self._namespace_mtls = None
        self._service = None
        self._validations = None
        self._virtual_services = None
        self._workloads = None
        self.discriminator = None
        if additional_details is not None:
            self.additional_details = additional_details
        if destination_rules is not None:
            self.destination_rules = destination_rules
        if endpoints is not None:
            self.endpoints = endpoints
        if health is not None:
            self.health = health
        if istio_sidecar is not None:
            self.istio_sidecar = istio_sidecar
        if namespace_mtls is not None:
            self.namespace_mtls = namespace_mtls
        if service is not None:
            self.service = service
        if validations is not None:
            self.validations = validations
        if virtual_services is not None:
            self.virtual_services = virtual_services
        if workloads is not None:
            self.workloads = workloads

    @property
    def additional_details(self):
        """Gets the additional_details of this ServiceDetails.  # noqa: E501


        :return: The additional_details of this ServiceDetails.  # noqa: E501
        :rtype: list[AdditionalItem]
        """
        return self._additional_details

    @additional_details.setter
    def additional_details(self, additional_details):
        """Sets the additional_details of this ServiceDetails.


        :param additional_details: The additional_details of this ServiceDetails.  # noqa: E501
        :type: list[AdditionalItem]
        """

        self._additional_details = additional_details

    @property
    def destination_rules(self):
        """Gets the destination_rules of this ServiceDetails.  # noqa: E501


        :return: The destination_rules of this ServiceDetails.  # noqa: E501
        :rtype: DestinationRules
        """
        return self._destination_rules

    @destination_rules.setter
    def destination_rules(self, destination_rules):
        """Sets the destination_rules of this ServiceDetails.


        :param destination_rules: The destination_rules of this ServiceDetails.  # noqa: E501
        :type: DestinationRules
        """

        self._destination_rules = destination_rules

    @property
    def endpoints(self):
        """Gets the endpoints of this ServiceDetails.  # noqa: E501


        :return: The endpoints of this ServiceDetails.  # noqa: E501
        :rtype: Endpoints
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """Sets the endpoints of this ServiceDetails.


        :param endpoints: The endpoints of this ServiceDetails.  # noqa: E501
        :type: Endpoints
        """

        self._endpoints = endpoints

    @property
    def health(self):
        """Gets the health of this ServiceDetails.  # noqa: E501


        :return: The health of this ServiceDetails.  # noqa: E501
        :rtype: ServiceHealth
        """
        return self._health

    @health.setter
    def health(self, health):
        """Sets the health of this ServiceDetails.


        :param health: The health of this ServiceDetails.  # noqa: E501
        :type: ServiceHealth
        """

        self._health = health

    @property
    def istio_sidecar(self):
        """Gets the istio_sidecar of this ServiceDetails.  # noqa: E501


        :return: The istio_sidecar of this ServiceDetails.  # noqa: E501
        :rtype: bool
        """
        return self._istio_sidecar

    @istio_sidecar.setter
    def istio_sidecar(self, istio_sidecar):
        """Sets the istio_sidecar of this ServiceDetails.


        :param istio_sidecar: The istio_sidecar of this ServiceDetails.  # noqa: E501
        :type: bool
        """

        self._istio_sidecar = istio_sidecar

    @property
    def namespace_mtls(self):
        """Gets the namespace_mtls of this ServiceDetails.  # noqa: E501


        :return: The namespace_mtls of this ServiceDetails.  # noqa: E501
        :rtype: MTLSStatus
        """
        return self._namespace_mtls

    @namespace_mtls.setter
    def namespace_mtls(self, namespace_mtls):
        """Sets the namespace_mtls of this ServiceDetails.


        :param namespace_mtls: The namespace_mtls of this ServiceDetails.  # noqa: E501
        :type: MTLSStatus
        """

        self._namespace_mtls = namespace_mtls

    @property
    def service(self):
        """Gets the service of this ServiceDetails.  # noqa: E501


        :return: The service of this ServiceDetails.  # noqa: E501
        :rtype: Service
        """
        return self._service

    @service.setter
    def service(self, service):
        """Sets the service of this ServiceDetails.


        :param service: The service of this ServiceDetails.  # noqa: E501
        :type: Service
        """

        self._service = service

    @property
    def validations(self):
        """Gets the validations of this ServiceDetails.  # noqa: E501


        :return: The validations of this ServiceDetails.  # noqa: E501
        :rtype: IstioValidations
        """
        return self._validations

    @validations.setter
    def validations(self, validations):
        """Sets the validations of this ServiceDetails.


        :param validations: The validations of this ServiceDetails.  # noqa: E501
        :type: IstioValidations
        """

        self._validations = validations

    @property
    def virtual_services(self):
        """Gets the virtual_services of this ServiceDetails.  # noqa: E501


        :return: The virtual_services of this ServiceDetails.  # noqa: E501
        :rtype: VirtualServices
        """
        return self._virtual_services

    @virtual_services.setter
    def virtual_services(self, virtual_services):
        """Sets the virtual_services of this ServiceDetails.


        :param virtual_services: The virtual_services of this ServiceDetails.  # noqa: E501
        :type: VirtualServices
        """

        self._virtual_services = virtual_services

    @property
    def workloads(self):
        """Gets the workloads of this ServiceDetails.  # noqa: E501


        :return: The workloads of this ServiceDetails.  # noqa: E501
        :rtype: WorkloadOverviews
        """
        return self._workloads

    @workloads.setter
    def workloads(self, workloads):
        """Sets the workloads of this ServiceDetails.


        :param workloads: The workloads of this ServiceDetails.  # noqa: E501
        :type: WorkloadOverviews
        """

        self._workloads = workloads

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServiceDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
